@@ -34,9 +34,7 @@
 #include <curl/curl.h>
 #include <zlib.h>
 
-#ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
-#endif
 
 #include "weechat.h"
 #include "wee-backtrace.h"
@@ -54,6 +52,7 @@
 #include "../gui/gui-bar-item.h"
 #include "../gui/gui-buffer.h"
 #include "../gui/gui-chat.h"
+#include "../gui/gui-completion.h"
 #include "../gui/gui-filter.h"
 #include "../gui/gui-hotlist.h"
 #include "../gui/gui-key.h"
@@ -92,6 +91,7 @@ debug_dump (int crash)
 
     gui_window_print_log ();
     gui_buffer_print_log ();
+    gui_completion_print_log ();
     gui_layout_print_log ();
     gui_key_print_log (NULL);
     gui_filter_print_log ();
@@ -538,7 +538,6 @@ debug_libs_cb (const void *pointer, void *data,
 #endif /* GCRYPT_VERSION */
 
     /* display gnutls version */
-#ifdef HAVE_GNUTLS
 #ifdef GNUTLS_VERSION
     gui_chat_printf (NULL, "    gnutls: %s%s",
                      GNUTLS_VERSION,
@@ -547,9 +546,6 @@ debug_libs_cb (const void *pointer, void *data,
     gui_chat_printf (NULL, "    gnutls: (?)%s",
                      (weechat_no_gnutls) ? " (not initialized)" : "");
 #endif /* GNUTLS_VERSION */
-#else
-    gui_chat_printf (NULL, "    gnutls: (not available)");
-#endif /* HAVE_GNUTLS */
 
     /* display curl version */
 #ifdef LIBCURL_VERSION
