@@ -1,7 +1,7 @@
 /*
  * wee-secure.c - secured data
  *
- * Copyright (C) 2013-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2013-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -25,13 +25,11 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <stdint.h>
-#include <time.h>
-#include <math.h>
 #include <gcrypt.h>
 
 #include "weechat.h"
 #include "wee-config-file.h"
+#include "wee-crypto.h"
 #include "wee-hashtable.h"
 #include "wee-secure.h"
 #include "wee-secure-config.h"
@@ -77,9 +75,11 @@ int
 secure_derive_key (const char *salt, const char *passphrase,
                    unsigned char *key, int length_key)
 {
-    unsigned char *buffer, *ptr_hash;
+    char *buffer, hash[512 / 8];
     int length, length_hash;
-    gcry_md_hd_t hd_md;
+
+    if (!salt || !passphrase || !key || (length_key < 1))
+        return 0;
 
     memset (key, 0, length_key);
 
@@ -93,26 +93,16 @@ secure_derive_key (const char *salt, const char *passphrase,
     memcpy (buffer + SECURE_SALT_SIZE, passphrase, strlen (passphrase));
 
     /* compute hash of buffer */
-    if (gcry_md_open (&hd_md, GCRY_MD_SHA512, 0) != 0)
+    if (!weecrypto_hash (buffer, length, GCRY_MD_SHA512, hash, &length_hash))
     {
         free (buffer);
         return 0;
     }
-    length_hash = gcry_md_get_algo_dlen (GCRY_MD_SHA512);
-    gcry_md_write (hd_md, buffer, length);
-    ptr_hash = gcry_md_read (hd_md, GCRY_MD_SHA512);
-    if (!ptr_hash)
-    {
-        gcry_md_close (hd_md);
-        free (buffer);
-        return 0;
-    }
 
     /* copy beginning of hash (or full hash) in the key */
-    memcpy (key, ptr_hash,
+    memcpy (key, hash,
             (length_hash > length_key) ? length_key : length_hash);
 
-    gcry_md_close (hd_md);
     free (buffer);
 
     return 1;
@@ -187,7 +177,7 @@ secure_encrypt_data (const char *data, int length_data,
     length_key = gcry_cipher_get_algo_keylen (cipher);
     key = malloc (length_key);
     if (!key)
-        goto encend;
+        goto encrypt_end;
     if (CONFIG_BOOLEAN(secure_config_crypt_salt))
         gcry_randomize (salt, SECURE_SALT_SIZE, GCRY_STRONG_RANDOM);
     else
@@ -202,14 +192,14 @@ secure_encrypt_data (const char *data, int length_data,
     if (!secure_derive_key (salt, passphrase, key, length_key))
     {
         rc = -2;
-        goto encend;
+        goto encrypt_end;
     }
 
     /* compute hash of data */
     if (gcry_md_open (hd_md, hash_algo, 0) != 0)
     {
         rc = -3;
-        goto encend;
+        goto encrypt_end;
     }
     hd_md_opened = 1;
     length_hash = gcry_md_get_algo_dlen (hash_algo);
@@ -218,14 +208,14 @@ secure_encrypt_data (const char *data, int length_data,
     if (!ptr_hash)
     {
         rc = -3;
-        goto encend;
+        goto encrypt_end;
     }
 
     /* build a buffer with hash + data */
     length_hash_data = length_hash + length_data;
     hash_and_data = malloc (length_hash_data);
     if (!hash_and_data)
-        goto encend;
+        goto encrypt_end;
     memcpy (hash_and_data, ptr_hash, length_hash);
     memcpy (hash_and_data + length_hash, data, length_data);
 
@@ -233,32 +223,32 @@ secure_encrypt_data (const char *data, int length_data,
     if (gcry_cipher_open (hd_cipher, cipher, GCRY_CIPHER_MODE_CFB, 0) != 0)
     {
         rc = -4;
-        goto encend;
+        goto encrypt_end;
     }
     hd_cipher_opened = 1;
     if (gcry_cipher_setkey (*hd_cipher, key, length_key) != 0)
     {
         rc = -5;
-        goto encend;
+        goto encrypt_end;
     }
     if (gcry_cipher_encrypt (*hd_cipher, hash_and_data, length_hash_data,
                              NULL, 0) != 0)
     {
         rc = -6;
-        goto encend;
+        goto encrypt_end;
     }
 
     /* create buffer and copy salt + encrypted hash/data into this buffer*/
     *length_encrypted = SECURE_SALT_SIZE + length_hash_data;
     *encrypted = malloc (*length_encrypted);
     if (!*encrypted)
-        goto encend;
+        goto encrypt_end;
     memcpy (*encrypted, salt, SECURE_SALT_SIZE);
     memcpy (*encrypted + SECURE_SALT_SIZE, hash_and_data, length_hash_data);
 
     rc = 0;
 
-encend:
+encrypt_end:
     if (hd_md)
     {
         if (hd_md_opened)
@@ -347,27 +337,27 @@ secure_decrypt_data (const char *buffer, int length_buffer,
     length_key = gcry_cipher_get_algo_keylen (cipher);
     key = malloc (length_key);
     if (!key)
-        goto decend;
+        goto decrypt_end;
     if (!secure_derive_key (buffer, passphrase, key, length_key))
     {
         rc = -3;
-        goto decend;
+        goto decrypt_end;
     }
 
     /* decrypt hash + data */
     decrypted_hash_data = malloc (length_buffer - SECURE_SALT_SIZE);
     if (!decrypted_hash_data)
-        goto decend;
+        goto decrypt_end;
     if (gcry_cipher_open (hd_cipher, cipher, GCRY_CIPHER_MODE_CFB, 0) != 0)
     {
         rc = -4;
-        goto decend;
+        goto decrypt_end;
     }
     hd_cipher_opened = 1;
     if (gcry_cipher_setkey (*hd_cipher, key, length_key) != 0)
     {
         rc = -5;
-        goto decend;
+        goto decrypt_end;
     }
     if (gcry_cipher_decrypt (*hd_cipher,
                              decrypted_hash_data,
@@ -376,14 +366,14 @@ secure_decrypt_data (const char *buffer, int length_buffer,
                              length_buffer - SECURE_SALT_SIZE) != 0)
     {
         rc = -6;
-        goto decend;
+        goto decrypt_end;
     }
 
     /* check if hash is OK for decrypted data */
     if (gcry_md_open (hd_md, hash_algo, 0) != 0)
     {
         rc = -7;
-        goto decend;
+        goto decrypt_end;
     }
     hd_md_opened = 1;
     gcry_md_write (*hd_md, decrypted_hash_data + length_hash,
@@ -392,25 +382,25 @@ secure_decrypt_data (const char *buffer, int length_buffer,
     if (!ptr_hash)
     {
         rc = -7;
-        goto decend;
+        goto decrypt_end;
     }
     if (memcmp (ptr_hash, decrypted_hash_data, length_hash) != 0)
     {
         rc = -8;
-        goto decend;
+        goto decrypt_end;
     }
 
     /* return the decrypted data */
     *length_decrypted = length_buffer - SECURE_SALT_SIZE - length_hash;
     *decrypted = malloc (*length_decrypted);
     if (!*decrypted)
-        goto decend;
+        goto decrypt_end;
 
     memcpy (*decrypted, decrypted_hash_data + length_hash, *length_decrypted);
 
     rc = 0;
 
-decend:
+decrypt_end:
     if (hd_md)
     {
         if (hd_md_opened)
@@ -456,6 +446,7 @@ secure_decrypt_data_not_decrypted (const char *passphrase)
     keys = string_split (hashtable_get_string (secure_hashtable_data_encrypted,
                                                "keys"),
                          ",",
+                         NULL,
                          WEECHAT_STRING_SPLIT_STRIP_LEFT
                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -502,195 +493,6 @@ secure_decrypt_data_not_decrypted (const char *passphrase)
     return num_ok;
 }
 
-/*
- * Generates a Time-based One-Time Password (TOTP), as described
- * in the RFC 6238.
- *
- * Returns:
- *   1: OK
- *   0: error
- */
-
-int
-secure_totp_generate_internal (const char *secret, int length_secret,
-                               uint64_t moving_factor, int digits,
-                               char *result)
-{
-    gcry_md_hd_t hd_md;
-    uint64_t moving_factor_swapped;
-    unsigned char *ptr_hash;
-    char hash[20];
-    int offset, length;
-    unsigned long bin_code;
-
-    if (gcry_md_open (&hd_md, GCRY_MD_SHA1, GCRY_MD_FLAG_HMAC) != 0)
-        return 0;
-
-    if (gcry_md_setkey (hd_md, secret, length_secret) != 0)
-    {
-        gcry_md_close (hd_md);
-        return 0;
-    }
-
-    moving_factor_swapped = (moving_factor >> 56)
-        | ((moving_factor << 40) & 0x00FF000000000000)
-        | ((moving_factor << 24) & 0x0000FF0000000000)
-        | ((moving_factor << 8) & 0x000000FF00000000)
-        | ((moving_factor >> 8) & 0x00000000FF000000)
-        | ((moving_factor >> 24) & 0x0000000000FF0000)
-        | ((moving_factor >> 40) & 0x000000000000FF00)
-        | (moving_factor << 56);
-
-    gcry_md_write (hd_md,
-                   &moving_factor_swapped, sizeof (moving_factor_swapped));
-
-    ptr_hash = gcry_md_read (hd_md, GCRY_MD_SHA1);
-    if (!ptr_hash)
-    {
-        gcry_md_close (hd_md);
-        return 0;
-    }
-
-    memcpy (hash, ptr_hash, sizeof (hash));
-
-    gcry_md_close (hd_md);
-
-    offset = hash[19] & 0xf;
-    bin_code = (hash[offset] & 0x7f) << 24
-        | (hash[offset+1] & 0xff) << 16
-        | (hash[offset+2] & 0xff) <<  8
-        | (hash[offset+3] & 0xff);
-
-    bin_code %= (unsigned long)(pow (10, digits));
-
-    length = snprintf (result, digits + 1, "%.*lu", digits, bin_code);
-    if (length != digits)
-        return 0;
-
-    return 1;
-}
-
-/*
- * Generates a Time-based One-Time Password (TOTP), as described
- * in the RFC 6238.
- *
- * Returns the password as string, NULL if error.
- *
- * Note: result must be freed after use.
- */
-
-char *
-secure_totp_generate (const char *secret_base32, time_t totp_time, int digits)
-{
-    char *result, *secret;
-    int length_secret, rc;
-    uint64_t moving_factor;
-
-    secret = NULL;
-    result = NULL;
-
-    if (!secret_base32 || !secret_base32[0]
-        || (digits < SECURE_TOTP_MIN_DIGITS)
-        || (digits > SECURE_TOTP_MAX_DIGITS))
-    {
-        goto error;
-    }
-
-    secret = malloc ((strlen (secret_base32) * 4) + 16 + 1);
-    if (!secret)
-        goto error;
-
-    length_secret = string_base32_decode (secret_base32, secret);
-    if (length_secret < 0)
-        goto error;
-
-    result = malloc (digits + 1);
-    if (!result)
-        goto error;
-
-    if (totp_time == 0)
-        totp_time = time (NULL);
-
-    moving_factor = totp_time / 30;
-
-    rc = secure_totp_generate_internal (secret, length_secret,
-                                        moving_factor, digits, result);
-    if (!rc)
-        goto error;
-
-    free (secret);
-
-    return result;
-
-error:
-    if (secret)
-        free (secret);
-    if (result)
-        free (result);
-    return NULL;
-}
-
-/*
- * Validates a Time-based One-Time Password (TOTP).
- *
- * Returns:
- *   1: OTP is OK
- *   0: OTP is invalid
- */
-
-int
-secure_totp_validate (const char *secret_base32, time_t totp_time, int window,
-                      const char *otp)
-{
-    char *secret, str_otp[16];
-    int length_secret, digits, rc, otp_ok;
-    uint64_t i, moving_factor;
-
-    secret = NULL;
-
-    if (!secret_base32 || !secret_base32[0] || (window < 0) || !otp || !otp[0])
-        goto error;
-
-    digits = strlen (otp);
-    if ((digits < SECURE_TOTP_MIN_DIGITS) || (digits > SECURE_TOTP_MAX_DIGITS))
-        goto error;
-
-    secret = malloc (strlen (secret_base32) + 1);
-    if (!secret)
-        goto error;
-
-    length_secret = string_base32_decode (secret_base32, secret);
-    if (length_secret < 0)
-        goto error;
-
-    if (totp_time == 0)
-        totp_time = time (NULL);
-
-    moving_factor = totp_time / 30;
-
-    otp_ok = 0;
-
-    for (i = moving_factor - window; i <= moving_factor + window; i++)
-    {
-        rc = secure_totp_generate_internal (secret, length_secret,
-                                            i, digits, str_otp);
-        if (rc && (strcmp (str_otp, otp) == 0))
-        {
-            otp_ok = 1;
-            break;
-        }
-    }
-
-    free (secret);
-
-    return otp_ok;
-
-error:
-    if (secret)
-        free (secret);
-    return 0;
-}
-
 /*
  * Initializes secured data.
  *
