@@ -76,6 +76,7 @@
 #include "../gui/gui-chat.h"
 #include "../gui/gui-color.h"
 #include "../gui/gui-completion.h"
+#include "../gui/gui-focus.h"
 #include "../gui/gui-key.h"
 #include "../gui/gui-layout.h"
 #include "../gui/gui-main.h"
@@ -88,6 +89,8 @@
 #define OPTION_NO_GCRYPT  1002
 
 int weechat_headless = 0;              /* 1 if running headless (no GUI)    */
+int weechat_daemon = 0;                /* 1 if daemonized (no foreground)   */
+int weechat_log_stdout = 0;            /* 1 to log messages on stdout       */
 int weechat_debug_core = 0;            /* debug level for core              */
 char *weechat_argv0 = NULL;            /* WeeChat binary file name (argv[0])*/
 int weechat_upgrading = 0;             /* =1 if WeeChat is upgrading        */
@@ -99,6 +102,8 @@ struct timeval weechat_current_start_timeval; /* start time used to display */
 volatile sig_atomic_t weechat_quit = 0;   /* = 1 if quit request from user  */
 volatile sig_atomic_t weechat_quit_signal = 0; /* signal received,          */
                                        /* WeeChat must quit                 */
+volatile sig_atomic_t weechat_reload_signal = 0; /* signal received,        */
+                                       /* WeeChat must reload confiuration  */
 char *weechat_home = NULL;             /* home dir. (default: ~/.weechat)   */
 int weechat_home_temp = 0;             /* 1 if using a temporary home       */
 int weechat_home_delete_on_exit = 0;   /* 1 if home is deleted on exit      */
@@ -193,6 +198,14 @@ weechat_display_usage ()
             stdout,
             _("                           (by default in headless mode "
               "WeeChat is blocking and does not run in background)\n"));
+        string_fprintf (
+            stdout,
+            _("      --stdout             display log messages on standard "
+              "output instead of writing them in log file\n"));
+        string_fprintf (
+            stdout,
+            _("                           (option ignored if option "
+              "\"--daemon\" is given)\n"));
         string_fprintf (stdout, "\n");
     }
 
@@ -676,13 +689,13 @@ weechat_locale_check ()
 }
 
 /*
- * Callback for system signal SIGHUP: quits WeeChat.
+ * Callback for system signal SIGHUP: reloads configuration.
  */
 
 void
 weechat_sighup ()
 {
-    weechat_quit_signal = SIGHUP;
+    weechat_reload_signal = SIGHUP;
 }
 
 /*
