@@ -100,6 +100,8 @@ struct t_weelist;
 
 /* global variables and functions */
 extern int weechat_headless;
+extern int weechat_daemon;
+extern int weechat_log_stdout;
 extern int weechat_debug_core;
 extern char *weechat_argv0;
 extern int weechat_upgrading;
@@ -109,6 +111,7 @@ extern struct timeval weechat_current_start_timeval;
 extern int weechat_upgrade_count;
 extern volatile sig_atomic_t weechat_quit;
 extern volatile sig_atomic_t weechat_quit_signal;
+extern volatile sig_atomic_t weechat_reload_signal;
 extern char *weechat_home;
 extern int weechat_home_temp;
 extern char *weechat_local_charset;
