@@ -83,6 +83,7 @@ gui_key_default_bindings (int context)
     {
         BIND(/* <enter>       */ "ctrl-M",             "/input return");
         BIND(/* <enter>       */ "ctrl-J",             "/input return");
+        BIND(/* m-<enter>     */ "meta-ctrl-M",        "/input insert \\n");
         BIND(/* <tab>         */ "ctrl-I",             "/input complete_next");
         BIND(/* s-<tab>       */ "meta2-Z",            "/input complete_previous");
         BIND(/* ^R            */ "ctrl-R",             "/input search_text_here");
@@ -176,6 +177,7 @@ gui_key_default_bindings (int context)
         BIND(/* m-<end>       */ "meta2-1;3F",         "/window scroll_bottom");
         BIND(/* m-n           */ "meta-n",             "/window scroll_next_highlight");
         BIND(/* m-p           */ "meta-p",             "/window scroll_previous_highlight");
+        BIND(/* m-N           */ "meta-N",             "/bar toggle nicklist");
         BIND(/* <f9>          */ "meta2-20~",          "/bar scroll title * -30%");
         BIND(/* <f10>         */ "meta2-21~",          "/bar scroll title * +30%");
         BIND(/* <f11>         */ "meta2-23~",          "/bar scroll nicklist * -100%");
@@ -546,29 +548,20 @@ gui_key_read_cb (const void *pointer, void *data, int fd)
 
     for (i = 0; i < ret; i++)
     {
-        /*
-         * add all chars, but ignore a newline ('\r' or '\n') after
-         * another one)
-         */
-        if ((i == 0)
-            || ((buffer[i] != '\r') && (buffer[i] != '\n'))
-            || ((buffer[i - 1] != '\r') && (buffer[i - 1] != '\n')))
+        if (gui_key_paste_pending && (buffer[i] == 25))
         {
-            if (gui_key_paste_pending && (buffer[i] == 25))
-            {
-                /* ctrl-Y: accept paste */
-                accept_paste = 1;
-            }
-            else if (gui_key_paste_pending && (buffer[i] == 14))
-            {
-                /* ctrl-N: cancel paste */
-                cancel_paste = 1;
-            }
-            else
-            {
-                gui_key_buffer_add (buffer[i]);
-                text_added_to_buffer = 1;
-            }
+            /* ctrl-Y: accept paste */
+            accept_paste = 1;
+        }
+        else if (gui_key_paste_pending && (buffer[i] == 14))
+        {
+            /* ctrl-N: cancel paste */
+            cancel_paste = 1;
+        }
+        else
+        {
+            gui_key_buffer_add (buffer[i]);
+            text_added_to_buffer = 1;
         }
     }
 
