@@ -1648,6 +1648,7 @@ gui_window_scroll_beyond_end (struct t_gui_window *window)
     {
         window->scroll->start_line = window->buffer->lines->last_line;
         window->scroll->start_line_pos = -1;
+        window->scroll->first_line_displayed = 0;
         gui_buffer_ask_chat_refresh (window->buffer, 2);
     }
 }
@@ -2529,6 +2530,7 @@ gui_window_set_title (const char *title)
     /* the following terminals support the xterm escape codes */
     else if ((strncmp (envterm, "xterm", 5) == 0)
              || (strncmp (envterm, "rxvt", 4) == 0)
+             || (strncmp (envterm, "alacritty", 9) == 0)
              || (strcmp (envterm, "Eterm") == 0)
              || (strcmp (envterm, "aixterm") == 0)
              || (strcmp (envterm, "iris-ansi") == 0)
