@@ -61,7 +61,8 @@ char *gui_bar_item_names[GUI_BAR_NUM_ITEMS] =
 { "input_paste", "input_prompt", "input_search", "input_text", "time",
   "buffer_count", "buffer_last_number", "buffer_plugin", "buffer_number",
   "buffer_name", "buffer_short_name", "buffer_modes", "buffer_filter",
-  "buffer_zoom", "buffer_nicklist_count", "scroll", "hotlist", "completion",
+  "buffer_zoom", "buffer_nicklist_count", "buffer_nicklist_count_groups",
+  "buffer_nicklist_count_all", "scroll", "hotlist", "completion",
   "buffer_title", "buffer_nicklist", "window_number", "mouse_status", "away"
 };
 char *gui_bar_items_default_for_bars[][2] =
@@ -963,6 +964,18 @@ gui_bar_item_input_text_cb (const void *pointer, void *data,
         }
     }
 
+    /*
+     * transform '\n' to '\r' so the newlines are displayed as real new lines
+     * instead of spaces
+     */
+    ptr_input2 = ptr_input;
+    while (ptr_input2 && ptr_input2[0])
+    {
+        if (ptr_input2[0] == '\n')
+            ptr_input2[0] = '\r';
+        ptr_input2 = (char *)utf8_next_char (ptr_input2);
+    }
+
     return ptr_input;
 }
 
@@ -1234,7 +1247,7 @@ gui_bar_item_buffer_filter_cb (const void *pointer, void *data,
 }
 
 /*
- * Bar item with number of nicks in buffer nicklist.
+ * Bar item with number of visible nicks in buffer nicklist.
  */
 
 char *
@@ -1253,6 +1266,68 @@ gui_bar_item_buffer_nicklist_count_cb (const void *pointer, void *data,
     (void) window;
     (void) extra_info;
 
+    if (!buffer || !buffer->nicklist)
+        return NULL;
+
+    snprintf (str_count, sizeof (str_count),
+              "%s%d",
+              gui_color_get_custom (gui_color_get_name (CONFIG_COLOR(config_color_status_nicklist_count))),
+              buffer->nicklist_nicks_visible_count);
+
+    return strdup (str_count);
+}
+
+/*
+ * Bar item with number of visible groups in buffer nicklist.
+ */
+
+char *
+gui_bar_item_buffer_nicklist_count_groups_cb (const void *pointer, void *data,
+                                              struct t_gui_bar_item *item,
+                                              struct t_gui_window *window,
+                                              struct t_gui_buffer *buffer,
+                                              struct t_hashtable *extra_info)
+{
+    char str_count[64];
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
+    if (!buffer || !buffer->nicklist)
+        return NULL;
+
+    snprintf (str_count, sizeof (str_count),
+              "%s%d",
+              gui_color_get_custom (gui_color_get_name (CONFIG_COLOR(config_color_status_nicklist_count))),
+              buffer->nicklist_groups_visible_count);
+
+    return strdup (str_count);
+}
+
+/*
+ * Bar item with number of visible groups and nicks in buffer nicklist.
+ */
+
+char *
+gui_bar_item_buffer_nicklist_count_all_cb (const void *pointer, void *data,
+                                           struct t_gui_bar_item *item,
+                                           struct t_gui_window *window,
+                                           struct t_gui_buffer *buffer,
+                                           struct t_hashtable *extra_info)
+{
+    char str_count[64];
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
     if (!buffer || !buffer->nicklist)
         return NULL;
 
@@ -1365,11 +1440,7 @@ gui_bar_item_hotlist_cb (const void *pointer, void *data,
 
     buffer_without_name_displayed = NULL;
     if (CONFIG_BOOLEAN(config_look_hotlist_unique_numbers) && last_gui_buffer)
-    {
-        buffer_without_name_displayed = malloc (last_gui_buffer->number);
-        if (buffer_without_name_displayed)
-            memset (buffer_without_name_displayed, 0, last_gui_buffer->number);
-    }
+        buffer_without_name_displayed = calloc (last_gui_buffer->number, 1);
 
     numbers_count = 0;
     names_count = 0;
@@ -1698,7 +1769,7 @@ gui_bar_item_buffer_nicklist_cb (const void *pointer, void *data,
                 && ptr_group->visible))
         {
             if (*nicklist[0])
-                string_dyn_concat (nicklist, "\n");
+                string_dyn_concat (nicklist, "\n", -1);
 
             if (ptr_nick)
             {
@@ -1706,7 +1777,7 @@ gui_bar_item_buffer_nicklist_cb (const void *pointer, void *data,
                 {
                     for (i = 0; i < ptr_nick->group->level; i++)
                     {
-                        string_dyn_concat (nicklist, " ");
+                        string_dyn_concat (nicklist, " ", -1);
                     }
                 }
                 if (ptr_nick->prefix_color)
@@ -1722,18 +1793,20 @@ gui_bar_item_buffer_nicklist_cb (const void *pointer, void *data,
                                 nicklist,
                                 gui_color_get_custom (
                                     gui_color_get_name (
-                                        CONFIG_COLOR(ptr_option))));
+                                        CONFIG_COLOR(ptr_option))),
+                                -1);
                         }
                     }
                     else
                     {
                         string_dyn_concat (nicklist,
                                            gui_color_get_custom (
-                                               ptr_nick->prefix_color));
+                                               ptr_nick->prefix_color),
+                                           -1);
                     }
                 }
                 if (ptr_nick->prefix)
-                    string_dyn_concat (nicklist, ptr_nick->prefix);
+                    string_dyn_concat (nicklist, ptr_nick->prefix, -1);
                 if (ptr_nick->color)
                 {
                     if (strchr (ptr_nick->color, '.'))
@@ -1747,23 +1820,25 @@ gui_bar_item_buffer_nicklist_cb (const void *pointer, void *data,
                                 nicklist,
                                 gui_color_get_custom (
                                     gui_color_get_name (
-                                        CONFIG_COLOR(ptr_option))));
+                                        CONFIG_COLOR(ptr_option))),
+                                -1);
                         }
                     }
                     else
                     {
                         string_dyn_concat (nicklist,
                                            gui_color_get_custom (
-                                               ptr_nick->color));
+                                               ptr_nick->color),
+                                           -1);
                     }
                 }
-                string_dyn_concat (nicklist, ptr_nick->name);
+                string_dyn_concat (nicklist, ptr_nick->name, -1);
             }
             else
             {
                 for (i = 0; i < ptr_group->level - 1; i++)
                 {
-                    string_dyn_concat (nicklist, " ");
+                    string_dyn_concat (nicklist, " ", -1);
                 }
                 if (ptr_group->color)
                 {
@@ -1778,19 +1853,22 @@ gui_bar_item_buffer_nicklist_cb (const void *pointer, void *data,
                                 nicklist,
                                 gui_color_get_custom (
                                     gui_color_get_name (
-                                        CONFIG_COLOR(ptr_option))));
+                                        CONFIG_COLOR(ptr_option))),
+                                -1);
                         }
                     }
                     else
                     {
                         string_dyn_concat (nicklist,
                                            gui_color_get_custom (
-                                               ptr_group->color));
+                                               ptr_group->color),
+                                           -1);
                     }
                 }
                 string_dyn_concat (nicklist,
                                    gui_nicklist_get_group_start (
-                                       ptr_group->name));
+                                       ptr_group->name),
+                                   -1);
             }
         }
         gui_nicklist_get_next_item (buffer, &ptr_group, &ptr_nick);
@@ -2246,7 +2324,7 @@ gui_bar_item_init ()
     gui_bar_item_hook_signal ("buffer_switch",
                               gui_bar_item_names[GUI_BAR_ITEM_BUFFER_ZOOM]);
 
-    /* buffer nicklist count */
+    /* buffer nicklist count: nicks displayed */
     gui_bar_item_new (NULL,
                       gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT],
                       &gui_bar_item_buffer_nicklist_count_cb, NULL, NULL);
@@ -2257,6 +2335,28 @@ gui_bar_item_init ()
     gui_bar_item_hook_signal ("nicklist_*",
                               gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT]);
 
+    /* buffer nicklist count: groups displayed */
+    gui_bar_item_new (NULL,
+                      gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_GROUPS],
+                      &gui_bar_item_buffer_nicklist_count_groups_cb, NULL, NULL);
+    gui_bar_item_hook_signal ("window_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_GROUPS]);
+    gui_bar_item_hook_signal ("buffer_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_GROUPS]);
+    gui_bar_item_hook_signal ("nicklist_*",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_GROUPS]);
+
+    /* buffer nicklist count: groups + nicks displayed */
+    gui_bar_item_new (NULL,
+                      gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_ALL],
+                      &gui_bar_item_buffer_nicklist_count_all_cb, NULL, NULL);
+    gui_bar_item_hook_signal ("window_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_ALL]);
+    gui_bar_item_hook_signal ("buffer_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_ALL]);
+    gui_bar_item_hook_signal ("nicklist_*",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_ALL]);
+
     /* scroll indicator */
     gui_bar_item_new (NULL,
                       gui_bar_item_names[GUI_BAR_ITEM_SCROLL],
