@@ -37,6 +37,8 @@ enum t_gui_bar_item_weechat
     GUI_BAR_ITEM_BUFFER_FILTER,
     GUI_BAR_ITEM_BUFFER_ZOOM,
     GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT,
+    GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_GROUPS,
+    GUI_BAR_ITEM_BUFFER_NICKLIST_COUNT_ALL,
     GUI_BAR_ITEM_SCROLL,
     GUI_BAR_ITEM_HOTLIST,
     GUI_BAR_ITEM_COMPLETION,
