@@ -43,6 +43,8 @@ enum t_gui_bar_option
     GUI_BAR_OPTION_COLOR_FG,            /* default text color for bar       */
     GUI_BAR_OPTION_COLOR_DELIM,         /* default delimiter color for bar  */
     GUI_BAR_OPTION_COLOR_BG,            /* default background color for bar */
+    GUI_BAR_OPTION_COLOR_BG_INACTIVE,   /* bg color for inactive window     */
+                                        /* (window bars only)               */
     GUI_BAR_OPTION_SEPARATOR,           /* true if separator line displayed */
     GUI_BAR_OPTION_ITEMS,               /* bar items                        */
     /* number of bar options */
@@ -140,6 +142,7 @@ extern struct t_gui_bar *gui_bar_new (const char *name,
                                       const char *color_fg,
                                       const char *color_delim,
                                       const char *color_bg,
+                                      const char *color_bg_inactive,
                                       const char *separator,
                                       const char *items);
 extern void gui_bar_use_temp_bars ();
