@@ -562,6 +562,179 @@ gui_color_convert_rgb_to_term (int rgb, int limit)
     return best_color;
 }
 
+/*
+ * Returns the size (in bytes) of the WeeChat color code at the beginning
+ * of "string".
+ *
+ * If "string" is NULL, empty or does not start with a color code,
+ * it returns 0.
+ *
+ * If "string" begins with multiple color codes, only the size of the first
+ * one is returned.
+ */
+
+int
+gui_color_code_size (const char *string)
+{
+    const char *ptr_string;
+
+    if (!string)
+        return 0;
+
+    ptr_string = string;
+
+    switch (ptr_string[0])
+    {
+        case GUI_COLOR_COLOR_CHAR:
+            ptr_string++;
+            switch (ptr_string[0])
+            {
+                case GUI_COLOR_FG_CHAR:
+                    ptr_string++;
+                    if (ptr_string[0] == GUI_COLOR_EXTENDED_CHAR)
+                    {
+                        ptr_string++;
+                        while (gui_color_attr_get_flag (ptr_string[0]) > 0)
+                        {
+                            ptr_string++;
+                        }
+                        if (ptr_string[0] && ptr_string[1] && ptr_string[2]
+                            && ptr_string[3] && ptr_string[4])
+                        {
+                            ptr_string += 5;
+                        }
+                    }
+                    else
+                    {
+                        while (gui_color_attr_get_flag (ptr_string[0]) > 0)
+                        {
+                            ptr_string++;
+                        }
+                        if (ptr_string[0] && ptr_string[1])
+                            ptr_string += 2;
+                    }
+                    break;
+                case GUI_COLOR_BG_CHAR:
+                    ptr_string++;
+                    if (ptr_string[0] == GUI_COLOR_EXTENDED_CHAR)
+                    {
+                        ptr_string++;
+                        if (ptr_string[0] && ptr_string[1] && ptr_string[2]
+                            && ptr_string[3] && ptr_string[4])
+                        {
+                            ptr_string += 5;
+                        }
+                    }
+                    else
+                    {
+                        if (ptr_string[0] && ptr_string[1])
+                            ptr_string += 2;
+                    }
+                    break;
+                case GUI_COLOR_FG_BG_CHAR:
+                    ptr_string++;
+                    if (ptr_string[0] == GUI_COLOR_EXTENDED_CHAR)
+                    {
+                        ptr_string++;
+                        while (gui_color_attr_get_flag (ptr_string[0]) > 0)
+                        {
+                            ptr_string++;
+                        }
+                        if (ptr_string[0] && ptr_string[1] && ptr_string[2]
+                            && ptr_string[3] && ptr_string[4])
+                        {
+                            ptr_string += 5;
+                        }
+                    }
+                    else
+                    {
+                        while (gui_color_attr_get_flag (ptr_string[0]) > 0)
+                        {
+                            ptr_string++;
+                        }
+                        if (ptr_string[0] && ptr_string[1])
+                            ptr_string += 2;
+                    }
+                    /*
+                     * note: the comma is an old separator not used any
+                     * more (since WeeChat 2.6), but we still use it here
+                     * so in case of/upgrade this will not break colors in
+                     * old messages
+                     */
+                    if ((ptr_string[0] == ',') || (ptr_string[0] == '~'))
+                    {
+                        if (ptr_string[1] == GUI_COLOR_EXTENDED_CHAR)
+                        {
+                            ptr_string += 2;
+                            if (ptr_string[0] && ptr_string[1]
+                                && ptr_string[2] && ptr_string[3]
+                                && ptr_string[4])
+                            {
+                                ptr_string += 5;
+                            }
+                        }
+                        else
+                        {
+                            ptr_string++;
+                            if (ptr_string[0] && ptr_string[1])
+                                ptr_string += 2;
+                        }
+                    }
+                    break;
+                case GUI_COLOR_EXTENDED_CHAR:
+                    ptr_string++;
+                    if ((isdigit (ptr_string[0])) && (isdigit (ptr_string[1]))
+                        && (isdigit (ptr_string[2])) && (isdigit (ptr_string[3]))
+                        && (isdigit (ptr_string[4])))
+                    {
+                        ptr_string += 5;
+                    }
+                    break;
+                case GUI_COLOR_EMPHASIS_CHAR:
+                    ptr_string++;
+                    break;
+                case GUI_COLOR_BAR_CHAR:
+                    ptr_string++;
+                    switch (ptr_string[0])
+                    {
+                        case GUI_COLOR_BAR_FG_CHAR:
+                        case GUI_COLOR_BAR_BG_CHAR:
+                        case GUI_COLOR_BAR_DELIM_CHAR:
+                        case GUI_COLOR_BAR_START_INPUT_CHAR:
+                        case GUI_COLOR_BAR_START_INPUT_HIDDEN_CHAR:
+                        case GUI_COLOR_BAR_MOVE_CURSOR_CHAR:
+                        case GUI_COLOR_BAR_START_ITEM:
+                        case GUI_COLOR_BAR_START_LINE_ITEM:
+                            ptr_string++;
+                            break;
+                    }
+                    break;
+                case GUI_COLOR_RESET_CHAR:
+                    ptr_string++;
+                    break;
+                default:
+                    if (isdigit (ptr_string[0]) && isdigit (ptr_string[1]))
+                        ptr_string += 2;
+                    break;
+            }
+            return ptr_string - string;
+            break;
+        case GUI_COLOR_SET_ATTR_CHAR:
+        case GUI_COLOR_REMOVE_ATTR_CHAR:
+            ptr_string++;
+            if (ptr_string[0])
+                ptr_string++;
+            return ptr_string - string;
+            break;
+        case GUI_COLOR_RESET_CHAR:
+            ptr_string++;
+            return ptr_string - string;
+            break;
+    }
+
+    return 0;
+}
+
 /*
  * Removes WeeChat color codes from a message.
  *
@@ -1019,16 +1192,16 @@ gui_color_add_ansi_flag (char **output, int flag)
     switch (flag)
     {
         case GUI_COLOR_EXTENDED_BOLD_FLAG:
-            string_dyn_concat (output, "\x1B[1m");
+            string_dyn_concat (output, "\x1B[1m", -1);
             break;
         case GUI_COLOR_EXTENDED_REVERSE_FLAG:
-            string_dyn_concat (output, "\x1B[7m");
+            string_dyn_concat (output, "\x1B[7m", -1);
             break;
         case GUI_COLOR_EXTENDED_ITALIC_FLAG:
-            string_dyn_concat (output, "\x1B[3m");
+            string_dyn_concat (output, "\x1B[3m", -1);
             break;
         case GUI_COLOR_EXTENDED_UNDERLINE_FLAG:
-            string_dyn_concat (output, "\x1B[4m");
+            string_dyn_concat (output, "\x1B[4m", -1);
             break;
         case GUI_COLOR_EXTENDED_KEEPATTR_FLAG:
             /* nothing to do here (really? not sure) */
@@ -1111,7 +1284,7 @@ gui_color_encode_ansi (const char *string)
                                     snprintf (str_concat, sizeof (str_concat),
                                               "\x1B[38;5;%dm",
                                               color);
-                                    string_dyn_concat (out, str_concat);
+                                    string_dyn_concat (out, str_concat, -1);
                                 }
                                 ptr_string += 5;
                             }
@@ -1138,7 +1311,7 @@ gui_color_encode_ansi (const char *string)
                                                   "\x1B[%dm",
                                                   (ansi_color < 8) ?
                                                   ansi_color + 30 : ansi_color - 8 + 90);
-                                        string_dyn_concat (out, str_concat);
+                                        string_dyn_concat (out, str_concat, -1);
                                     }
                                 }
                                 ptr_string += 2;
@@ -1162,7 +1335,7 @@ gui_color_encode_ansi (const char *string)
                                     snprintf (str_concat, sizeof (str_concat),
                                               "\x1B[48;5;%dm",
                                               color);
-                                    string_dyn_concat (out, str_concat);
+                                    string_dyn_concat (out, str_concat, -1);
                                 }
                                 ptr_string += 5;
                             }
@@ -1184,7 +1357,7 @@ gui_color_encode_ansi (const char *string)
                                                   "\x1B[%dm",
                                                   (ansi_color < 8) ?
                                                   ansi_color + 40 : ansi_color - 8 + 100);
-                                        string_dyn_concat (out, str_concat);
+                                        string_dyn_concat (out, str_concat, -1);
                                     }
                                 }
                                 ptr_string += 2;
@@ -1213,7 +1386,7 @@ gui_color_encode_ansi (const char *string)
                                     snprintf (str_concat, sizeof (str_concat),
                                               "\x1B[38;5;%dm",
                                               color);
-                                    string_dyn_concat (out, str_concat);
+                                    string_dyn_concat (out, str_concat, -1);
                                 }
                                 ptr_string += 5;
                             }
@@ -1240,7 +1413,7 @@ gui_color_encode_ansi (const char *string)
                                                   "\x1B[%dm",
                                                   (ansi_color < 8) ?
                                                   ansi_color + 30 : ansi_color - 8 + 90);
-                                        string_dyn_concat (out, str_concat);
+                                        string_dyn_concat (out, str_concat, -1);
                                     }
                                 }
                                 ptr_string += 2;
@@ -1270,7 +1443,7 @@ gui_color_encode_ansi (const char *string)
                                         snprintf (str_concat, sizeof (str_concat),
                                                   "\x1B[48;5;%dm",
                                                   color);
-                                        string_dyn_concat (out, str_concat);
+                                        string_dyn_concat (out, str_concat, -1);
                                     }
                                     ptr_string += 5;
                                 }
@@ -1293,7 +1466,7 @@ gui_color_encode_ansi (const char *string)
                                                       "\x1B[%dm",
                                                       (ansi_color < 8) ?
                                                       ansi_color + 40 : ansi_color - 8 + 100);
-                                            string_dyn_concat (out, str_concat);
+                                            string_dyn_concat (out, str_concat, -1);
                                         }
                                     }
                                     ptr_string += 2;
@@ -1316,7 +1489,7 @@ gui_color_encode_ansi (const char *string)
                                 snprintf (str_concat, sizeof (str_concat),
                                           "\x1B[38;5;%dm",
                                           color);
-                                string_dyn_concat (out, str_concat);
+                                string_dyn_concat (out, str_concat, -1);
                             }
                             ptr_string += 5;
                         }
@@ -1342,7 +1515,7 @@ gui_color_encode_ansi (const char *string)
                         break;
                     case GUI_COLOR_RESET_CHAR:
                         ptr_string++;
-                        string_dyn_concat (out, "\x1B[39m\x1B[49m");
+                        string_dyn_concat (out, "\x1B[39m\x1B[49m", -1);
                         break;
                     default:
                         if (isdigit (ptr_string[0]) && isdigit (ptr_string[1]))
@@ -1359,40 +1532,40 @@ gui_color_encode_ansi (const char *string)
                                 bg = gui_color[color]->background;
                                 attrs = gui_color_get_extended_flags (
                                     gui_color[color]->attributes);
-                                string_dyn_concat (out, "\x1B[0m");
+                                string_dyn_concat (out, "\x1B[0m", -1);
                                 if (attrs & GUI_COLOR_EXTENDED_BOLD_FLAG)
-                                    string_dyn_concat (out, "\x1B[1m");
+                                    string_dyn_concat (out, "\x1B[1m", -1);
                                 if (attrs & GUI_COLOR_EXTENDED_REVERSE_FLAG)
-                                    string_dyn_concat (out, "\x1B[7m");
+                                    string_dyn_concat (out, "\x1B[7m", -1);
                                 if (attrs & GUI_COLOR_EXTENDED_ITALIC_FLAG)
-                                    string_dyn_concat (out, "\x1B[3m");
+                                    string_dyn_concat (out, "\x1B[3m", -1);
                                 if (attrs & GUI_COLOR_EXTENDED_UNDERLINE_FLAG)
-                                    string_dyn_concat (out, "\x1B[4m");
+                                    string_dyn_concat (out, "\x1B[4m", -1);
                                 if ((fg > 0) && (fg & GUI_COLOR_EXTENDED_FLAG))
                                     fg &= GUI_COLOR_EXTENDED_MASK;
                                 if ((bg > 0) && (bg & GUI_COLOR_EXTENDED_FLAG))
                                     bg &= GUI_COLOR_EXTENDED_MASK;
                                 if (fg < 0)
                                 {
-                                    string_dyn_concat (out, "\x1B[39m");
+                                    string_dyn_concat (out, "\x1B[39m", -1);
                                 }
                                 else
                                 {
                                     snprintf (str_concat, sizeof (str_concat),
                                               "\x1B[38;5;%dm",
                                               fg);
-                                    string_dyn_concat (out, str_concat);
+                                    string_dyn_concat (out, str_concat, -1);
                                 }
                                 if (bg < 0)
                                 {
-                                    string_dyn_concat (out, "\x1B[49m");
+                                    string_dyn_concat (out, "\x1B[49m", -1);
                                 }
                                 else
                                 {
                                     snprintf (str_concat, sizeof (str_concat),
                                               "\x1B[48;5;%dm",
                                               bg);
-                                    string_dyn_concat (out, str_concat);
+                                    string_dyn_concat (out, str_concat, -1);
                                 }
                             }
                             ptr_string += 2;
@@ -1407,16 +1580,16 @@ gui_color_encode_ansi (const char *string)
                     switch (ptr_string[0])
                     {
                         case GUI_COLOR_ATTR_BOLD_CHAR:
-                            string_dyn_concat (out, "\x1B[1m");
+                            string_dyn_concat (out, "\x1B[1m", -1);
                             break;
                         case GUI_COLOR_ATTR_REVERSE_CHAR:
-                            string_dyn_concat (out, "\x1B[7m");
+                            string_dyn_concat (out, "\x1B[7m", -1);
                             break;
                         case GUI_COLOR_ATTR_ITALIC_CHAR:
-                            string_dyn_concat (out, "\x1B[3m");
+                            string_dyn_concat (out, "\x1B[3m", -1);
                             break;
                         case GUI_COLOR_ATTR_UNDERLINE_CHAR:
-                            string_dyn_concat (out, "\x1B[4m");
+                            string_dyn_concat (out, "\x1B[4m", -1);
                             break;
                     }
                     ptr_string++;
@@ -1429,32 +1602,30 @@ gui_color_encode_ansi (const char *string)
                     switch (ptr_string[0])
                     {
                         case GUI_COLOR_ATTR_BOLD_CHAR:
-                            string_dyn_concat (out, "\x1B[21m");
+                            string_dyn_concat (out, "\x1B[21m", -1);
                             break;
                         case GUI_COLOR_ATTR_REVERSE_CHAR:
-                            string_dyn_concat (out, "\x1B[27m");
+                            string_dyn_concat (out, "\x1B[27m", -1);
                             break;
                         case GUI_COLOR_ATTR_ITALIC_CHAR:
-                            string_dyn_concat (out, "\x1B[23m");
+                            string_dyn_concat (out, "\x1B[23m", -1);
                             break;
                         case GUI_COLOR_ATTR_UNDERLINE_CHAR:
-                            string_dyn_concat (out, "\x1B[24m");
+                            string_dyn_concat (out, "\x1B[24m", -1);
                             break;
                     }
                     ptr_string++;
                 }
                 break;
             case GUI_COLOR_RESET_CHAR:
-                string_dyn_concat (out, "\x1B[0m");
+                string_dyn_concat (out, "\x1B[0m", -1);
                 ptr_string++;
                 break;
             default:
                 length = utf8_char_size ((char *)ptr_string);
                 if (length == 0)
                     length = 1;
-                memcpy (str_concat, ptr_string, length);
-                str_concat[length] = '\0';
-                string_dyn_concat (out, str_concat);
+                string_dyn_concat (out, (const char *)ptr_string, length);
                 ptr_string += length;
                 break;
         }
