@@ -28,6 +28,7 @@
 
 #include "../core/weechat.h"
 #include "../core/wee-hashtable.h"
+#include "../core/wee-hook.h"
 #include "../core/wee-string.h"
 #include "../plugins/plugin.h"
 #include "gui-bar.h"
@@ -132,7 +133,7 @@ gui_focus_buffer_localvar_map_cb (void *data,
 }
 
 /*
- * Adds two focus info into hashtable.
+ * Adds focus info into hashtable.
  *
  * Returns pointer to new hashtable.
  *
@@ -154,7 +155,8 @@ gui_focus_to_hashtable (struct t_gui_focus_info *focus_info, const char *key)
         return NULL;
 
     /* key (key from keyboard or mouse event) */
-    HASHTABLE_SET_STR("_key", key);
+    if (key)
+        HASHTABLE_SET_STR("_key", key);
 
     /* x,y */
     HASHTABLE_SET_INT("_x", focus_info->x);
@@ -239,6 +241,7 @@ gui_focus_to_hashtable (struct t_gui_focus_info *focus_info, const char *key)
     HASHTABLE_SET_STR_NOT_NULL("_chat_eol", focus_info->chat_eol);
 
     /* bar/item */
+    HASHTABLE_SET_POINTER("_bar_window", focus_info->bar_window);
     if (focus_info->bar_window)
     {
         HASHTABLE_SET_STR("_bar_name", ((focus_info->bar_window)->bar)->name);
@@ -255,3 +258,62 @@ gui_focus_to_hashtable (struct t_gui_focus_info *focus_info, const char *key)
 
     return hashtable;
 }
+
+/*
+ * Returns GUI focus info with hashtable "gui_focus_info".
+ */
+
+struct t_hashtable *
+gui_focus_info_hashtable_gui_focus_info_cb (const void *pointer, void *data,
+                                            const char *info_name,
+                                            struct t_hashtable *hashtable)
+{
+    char *error;
+    const char *ptr_value;
+    int x, y;
+    struct t_gui_focus_info *focus_info;
+    struct t_hashtable *focus_hashtable, *ret_hashtable;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) info_name;
+
+    if (!hashtable)
+        return NULL;
+
+    /* parse coordinates */
+    ptr_value = hashtable_get (hashtable, "x");
+    if (!ptr_value)
+        return NULL;
+    error = NULL;
+    x = (int)strtol (ptr_value, &error, 10);
+    if (!error || error[0])
+        return NULL;
+
+    ptr_value = hashtable_get (hashtable, "y");
+    if (!ptr_value)
+        return NULL;
+    error = NULL;
+    y = (int)strtol (ptr_value, &error, 10);
+    if (!error || error[0])
+        return NULL;
+
+    /* get focus info */
+    focus_info = gui_focus_get_info (x, y);
+    if (!focus_info)
+        return NULL;
+
+    /* convert to hashtable */
+    focus_hashtable = gui_focus_to_hashtable (focus_info, NULL); /* no key */
+    gui_focus_free_info (focus_info);
+    if (!focus_hashtable)
+        return NULL;
+
+    /* run hook_focus callbacks that add extra data */
+    ret_hashtable = hook_focus_get_data (focus_hashtable, NULL); /* no gesture */
+
+    free (focus_hashtable);
+
+    return ret_hashtable;
+}
