@@ -54,7 +54,7 @@
  */
 
 struct t_gui_lines *
-gui_lines_alloc ()
+gui_line_lines_alloc ()
 {
     struct t_gui_lines *new_lines;
 
@@ -81,7 +81,7 @@ gui_lines_alloc ()
  */
 
 void
-gui_lines_free (struct t_gui_lines *lines)
+gui_line_lines_free (struct t_gui_lines *lines)
 {
     if (!lines)
         return;
@@ -96,6 +96,9 @@ gui_lines_free (struct t_gui_lines *lines)
 void
 gui_line_tags_alloc (struct t_gui_line_data *line_data, const char *tags)
 {
+    if (!line_data)
+        return;
+
     if (tags)
     {
         line_data->tags_array = string_split_shared (tags, ",", NULL, 0, 0,
@@ -380,6 +383,9 @@ gui_line_get_align (struct t_gui_buffer *buffer, struct t_gui_line *line,
 int
 gui_line_is_displayed (struct t_gui_line *line)
 {
+    if (!line)
+        return 0;
+
     /* line is hidden if filters are enabled and flag "displayed" is not set */
     if (gui_filters_enabled && !line->data->displayed)
         return 0;
@@ -620,6 +626,9 @@ gui_line_has_tag_no_filter (struct t_gui_line_data *line_data)
 {
     int i;
 
+    if (!line_data)
+        return 0;
+
     for (i = 0; i < line_data->tags_count; i++)
     {
         if (strcmp (line_data->tags_array[i], GUI_FILTER_TAG_NO_FILTER) == 0)
@@ -727,6 +736,9 @@ gui_line_get_nick_tag (struct t_gui_line *line)
 {
     const char *tag;
 
+    if (!line)
+        return NULL;
+
     tag = gui_line_search_tag_starting_with (line, "nick_");
     if (!tag)
         return NULL;
@@ -1229,77 +1241,80 @@ gui_line_free_all (struct t_gui_buffer *buffer)
 }
 
 /*
- * Gets notify level for a line.
+ * Gets max notify level for a line, according to the nick.
  *
- * Returns notify level of line, -1 if tag "notify_none" is found (meaning no
- * notify at all for line).
+ * Returns max notify level, between -1 and GUI_HOTLIST_HIGHLIGHT.
  */
 
 int
-gui_line_get_notify_level (struct t_gui_line *line)
+gui_line_get_max_notify_level (struct t_gui_line *line)
 {
-    int i, notify_level, *max_notify_level;
+    int max_notify_level, *ptr_max_notify_level;
     const char *nick;
 
-    notify_level = GUI_HOTLIST_LOW;
+    max_notify_level = GUI_HOTLIST_HIGHLIGHT;
+
+    nick = gui_line_get_nick_tag (line);
+    if (nick)
+    {
+        ptr_max_notify_level = hashtable_get (
+            line->data->buffer->hotlist_max_level_nicks,
+            nick);
+        if (ptr_max_notify_level)
+            max_notify_level = *ptr_max_notify_level;
+    }
+
+    return max_notify_level;
+}
+
+/*
+ * Sets the notify level in a line:
+ *   -1: no notify at all
+ *    0: low (GUI_HOTLIST_LOW)
+ *    1: message (GUI_HOTLIST_MESSAGE)
+ *    2: private message (GUI_HOTLIST_PRIVATE)
+ *    3: message with highlight (GUI_HOTLIST_HIGHLIGHT)
+ */
+
+void
+gui_line_set_notify_level (struct t_gui_line *line, int max_notify_level)
+{
+    int i;
+
+    line->data->notify_level = GUI_HOTLIST_LOW;
 
     for (i = 0; i < line->data->tags_count; i++)
     {
         if (string_strcasecmp (line->data->tags_array[i], "notify_none") == 0)
-            notify_level = -1;
-        if (string_strcasecmp (line->data->tags_array[i], "notify_highlight") == 0)
-            notify_level = GUI_HOTLIST_HIGHLIGHT;
-        if (string_strcasecmp (line->data->tags_array[i], "notify_private") == 0)
-            notify_level = GUI_HOTLIST_PRIVATE;
+            line->data->notify_level = -1;
         if (string_strcasecmp (line->data->tags_array[i], "notify_message") == 0)
-            notify_level = GUI_HOTLIST_MESSAGE;
+            line->data->notify_level = GUI_HOTLIST_MESSAGE;
+        if (string_strcasecmp (line->data->tags_array[i], "notify_private") == 0)
+            line->data->notify_level = GUI_HOTLIST_PRIVATE;
+        if (string_strcasecmp (line->data->tags_array[i], "notify_highlight") == 0)
+            line->data->notify_level = GUI_HOTLIST_HIGHLIGHT;
     }
 
-    max_notify_level = NULL;
-    nick = gui_line_get_nick_tag (line);
-    if (nick)
-    {
-        max_notify_level = hashtable_get (line->data->buffer->hotlist_max_level_nicks,
-                                          nick);
-    }
-    if (max_notify_level && (*max_notify_level < notify_level))
-        notify_level = *max_notify_level;
-
-    return notify_level;
+    if (line->data->notify_level > max_notify_level)
+        line->data->notify_level = max_notify_level;
 }
 
 /*
- * Gets highlight flag for a line, using the notify level in the line.
- *
- * Returns 1 for highlight otherwise 0.
+ * Sets highlight flag in a line:
+ *   0: no highlight
+ *   1: highlight
  */
 
-int
-gui_line_get_highlight (struct t_gui_line *line)
+void
+gui_line_set_highlight (struct t_gui_line *line, int max_notify_level)
 {
-    int highlight, *max_notify_level;
-    const char *nick;
-
     if (line->data->notify_level == GUI_HOTLIST_HIGHLIGHT)
-    {
-        highlight = 1;
-    }
+        line->data->highlight = 1;
     else
     {
-        max_notify_level = NULL;
-        nick = gui_line_get_nick_tag (line);
-        if (nick)
-        {
-            max_notify_level = hashtable_get (line->data->buffer->hotlist_max_level_nicks,
-                                              nick);
-        }
-        if (max_notify_level && (*max_notify_level < GUI_HOTLIST_HIGHLIGHT))
-            highlight = 0;
-        else
-            highlight = gui_line_has_highlight (line);
+        line->data->highlight = (max_notify_level == GUI_HOTLIST_HIGHLIGHT) ?
+            gui_line_has_highlight (line) : 0;
     }
-
-    return highlight;
 }
 
 /*
@@ -1313,6 +1328,7 @@ gui_line_new (struct t_gui_buffer *buffer, int y, time_t date,
 {
     struct t_gui_line *new_line;
     struct t_gui_line_data *new_line_data;
+    int max_notify_level;
 
     /* create new line */
     new_line = malloc (sizeof (*new_line));
@@ -1344,8 +1360,11 @@ gui_line_new (struct t_gui_buffer *buffer, int y, time_t date,
             (char *)string_shared_get (prefix) : ((date != 0) ? (char *)string_shared_get ("") : NULL);
         new_line->data->prefix_length = (prefix) ?
             gui_chat_strlen_screen (prefix) : 0;
-        new_line->data->notify_level = gui_line_get_notify_level (new_line);
-        new_line->data->highlight = gui_line_get_highlight (new_line);
+        max_notify_level = gui_line_get_max_notify_level (new_line);
+        gui_line_set_notify_level (new_line, max_notify_level);
+        gui_line_set_highlight (new_line, max_notify_level);
+        if (new_line->data->highlight && (new_line->data->notify_level >= 0))
+            new_line->data->notify_level = GUI_HOTLIST_HIGHLIGHT;
     }
     else
     {
@@ -1386,6 +1405,7 @@ gui_line_hook_update (struct t_gui_line *line,
     long value;
     char *error;
     int rc, tags_updated, notify_level_updated, highlight_updated;
+    int max_notify_level;
 
     tags_updated = 0;
     notify_level_updated = 0;
@@ -1531,16 +1551,31 @@ gui_line_hook_update (struct t_gui_line *line,
         line->data->message = (ptr_value2) ? strdup (ptr_value2) : NULL;
     }
 
+    max_notify_level = gui_line_get_max_notify_level (line);
+
     /* if tags were updated but not notify_level, adjust notify level */
     if (tags_updated && !notify_level_updated)
-        line->data->notify_level = gui_line_get_notify_level (line);
+        gui_line_set_notify_level (line, max_notify_level);
 
     /* adjust flag "displayed" if tags were updated */
     if (tags_updated)
         line->data->displayed = gui_filter_check_line (line->data);
 
     if ((tags_updated || notify_level_updated) && !highlight_updated)
-        line->data->highlight = gui_line_get_highlight (line);
+    {
+        gui_line_set_highlight (line, max_notify_level);
+        if (line->data->highlight && !notify_level_updated
+            && (line->data->notify_level >= 0))
+        {
+            line->data->notify_level = GUI_HOTLIST_HIGHLIGHT;
+        }
+    }
+
+    if (!notify_level_updated && highlight_updated && line->data->highlight
+        && (line->data->notify_level >= 0))
+    {
+        line->data->notify_level = GUI_HOTLIST_HIGHLIGHT;
+    }
 }
 
 /*
@@ -1581,7 +1616,8 @@ gui_line_add (struct t_gui_line *line)
     /* update hotlist and/or send signals for line */
     if (line->data->displayed)
     {
-        if (line->data->highlight)
+        if ((line->data->notify_level >= GUI_HOTLIST_MIN)
+            && line->data->highlight)
         {
             (void) gui_hotlist_add (line->data->buffer,
                                     GUI_HOTLIST_HIGHLIGHT, NULL);
@@ -1786,7 +1822,7 @@ gui_line_mix_buffers (struct t_gui_buffer *buffer)
         return;
 
     /* mix all lines (sorting by date) to a new structure "new_lines" */
-    new_lines = gui_lines_alloc ();
+    new_lines = gui_line_lines_alloc ();
     if (!new_lines)
         return;
     ptr_line1 = ptr_buffer_found->lines->first_line;
