@@ -29,13 +29,15 @@
 #include "buflist-config.h"
 
 
-struct t_gui_bar_item *buflist_bar_item_buflist[BUFLIST_BAR_NUM_ITEMS];
+struct t_gui_bar_item *buflist_bar_item_buflist[BUFLIST_BAR_NUM_ITEMS] =
+{ NULL, NULL, NULL };
 struct t_hashtable *buflist_hashtable_pointers = NULL;
 struct t_hashtable *buflist_hashtable_extra_vars = NULL;
 struct t_hashtable *buflist_hashtable_options_conditions = NULL;
-struct t_arraylist *buflist_list_buffers[BUFLIST_BAR_NUM_ITEMS];
+struct t_arraylist *buflist_list_buffers[BUFLIST_BAR_NUM_ITEMS] =
+{ NULL, NULL, NULL };
 
-int old_line_number_current_buffer[BUFLIST_BAR_NUM_ITEMS];
+int old_line_number_current_buffer[BUFLIST_BAR_NUM_ITEMS] = { -1, -1, -1 };
 
 
 /*
@@ -81,6 +83,24 @@ buflist_bar_item_get_index (const char *item_name)
     return -1;
 }
 
+/*
+ * Returns the bar item index with a bar item pointer, -1 if not found.
+ */
+
+int
+buflist_bar_item_get_index_with_pointer (struct t_gui_bar_item *item)
+{
+    int i;
+
+    for (i = 0; i < BUFLIST_BAR_NUM_ITEMS; i++)
+    {
+        if (buflist_bar_item_buflist[i] == item)
+            return i;
+    }
+
+    return -1;
+}
+
 /*
  * Updates buflist bar item if buflist is enabled (or if force argument is 1).
  */
@@ -307,7 +327,8 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
     item_index = (int)((unsigned long)pointer);
 
     weechat_hashtable_set (buflist_hashtable_pointers, "bar_item", item);
-    weechat_hashtable_set (buflist_hashtable_pointers, "window", window);
+    if (window)
+        weechat_hashtable_set (buflist_hashtable_pointers, "window", window);
 
     ptr_format = buflist_config_format_buffer_eval;
     ptr_format_current = buflist_config_format_buffer_current_eval;
@@ -332,7 +353,7 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
         16, 0, 1,
         NULL, NULL, NULL, NULL);
 
-    buffers = buflist_sort_buffers ();
+    buffers = buflist_sort_buffers (item);
 
     num_buffers = weechat_arraylist_size (buffers);
     for (i = 0; i < num_buffers; i++)
@@ -521,15 +542,19 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
                             weechat_string_dyn_concat (
                                 hotlist,
                                 weechat_config_string (
-                                    buflist_config_format_hotlist_separator));
+                                    buflist_config_format_hotlist_separator),
+                                -1);
                         }
                         weechat_string_dyn_concat (
                             hotlist,
                             weechat_config_string (
-                                buflist_config_format_hotlist_level[j]));
+                                buflist_config_format_hotlist_level[j]),
+                            -1);
                         snprintf (str_hotlist_count, sizeof (str_hotlist_count),
                                   "%d", count);
-                        weechat_string_dyn_concat (hotlist, str_hotlist_count);
+                        weechat_string_dyn_concat (hotlist,
+                                                   str_hotlist_count,
+                                                   -1);
                     }
                 }
                 str_hotlist = *hotlist;
@@ -585,7 +610,7 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
         if (weechat_config_boolean (buflist_config_look_add_newline)
             && *buflist[0])
         {
-            if (!weechat_string_dyn_concat (buflist, "\n"))
+            if (!weechat_string_dyn_concat (buflist, "\n", -1))
                 goto error;
         }
 
@@ -597,7 +622,7 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
             NULL);
 
         /* concatenate string */
-        rc = weechat_string_dyn_concat (buflist, line);
+        rc = weechat_string_dyn_concat (buflist, line, -1);
         free (line);
         if (!rc)
             goto error;
