@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_FIFO_CONFIG_H
-#define WEECHAT_FIFO_CONFIG_H 1
+#ifndef WEECHAT_PLUGIN_FIFO_CONFIG_H
+#define WEECHAT_PLUGIN_FIFO_CONFIG_H
 
 #define FIFO_CONFIG_NAME "fifo"
 
@@ -31,4 +31,4 @@ extern int fifo_config_read ();
 extern int fifo_config_write ();
 extern void fifo_config_free ();
 
-#endif /* WEECHAT_FIFO_CONFIG_H */
+#endif /* WEECHAT_PLUGIN_FIFO_CONFIG_H */
