@@ -916,24 +916,9 @@ weechat_guile_command_cb (const void *pointer, void *data,
                 else
                     break;
             }
-            /*
-             * FIXME: this does not yet work with Guile >= 2.2, so the eval
-             * feature is temporarily disabled, waiting for a fix
-             */
-            /*
             if (!weechat_guile_eval (buffer, send_to_buffer_as_input,
                                      exec_commands, ptr_code))
                 WEECHAT_COMMAND_ERROR;
-            */
-            /* TODO: fix /guile eval */
-            (void) buffer;
-            (void) ptr_code;
-            (void) send_to_buffer_as_input;
-            (void) exec_commands;
-            weechat_printf (NULL,
-                            _("%sCommand \"/%s eval\" is not yet implemented"),
-                            weechat_prefix ("error"),
-                            weechat_guile_plugin->name);
         }
         else
             WEECHAT_COMMAND_ERROR;
@@ -1151,11 +1136,10 @@ weechat_guile_port_fill_input (SCM port, SCM dst, size_t start, size_t count)
 {
     /* make C compiler happy */
     (void) port;
-    (void) dst;
-    (void) start;
-    (void) count;
 
-    return ' ';
+    memset (SCM_BYTEVECTOR_CONTENTS (dst) + start, ' ', count);
+
+    return count;
 }
 #else
 /* Guile < 2.2 */
@@ -1179,12 +1163,12 @@ size_t
 weechat_guile_port_write (SCM port, SCM src, size_t start, size_t count)
 {
     char *data2, *ptr_data, *ptr_newline;
-    const char *data;
+    const signed char *data;
 
     /* make C compiler happy */
     (void) port;
 
-    data = scm_to_locale_string (src);
+    data = SCM_BYTEVECTOR_CONTENTS (src);
 
     data2 = malloc (count + 1);
     if (!data2)
@@ -1196,13 +1180,15 @@ weechat_guile_port_write (SCM port, SCM src, size_t start, size_t count)
     ptr_data = data2;
     while ((ptr_newline = strchr (ptr_data, '\n')) != NULL)
     {
-        ptr_newline[0] = '\0';
-        weechat_string_dyn_concat (guile_buffer_output, ptr_data);
+        weechat_string_dyn_concat (guile_buffer_output,
+                                   ptr_data,
+                                   ptr_newline - ptr_data);
         weechat_guile_output_flush ();
-        ptr_newline[0] = '\n';
         ptr_data = ++ptr_newline;
     }
-    weechat_string_dyn_concat (guile_buffer_output, ptr_data);
+    weechat_string_dyn_concat (guile_buffer_output, ptr_data, -1);
+
+    free (data2);
 
     return count;
 }
@@ -1226,13 +1212,15 @@ weechat_guile_port_write (SCM port, const void *data, size_t size)
     ptr_data = data2;
     while ((ptr_newline = strchr (ptr_data, '\n')) != NULL)
     {
-        ptr_newline[0] = '\0';
-        weechat_string_dyn_concat (guile_buffer_output, ptr_data);
+        weechat_string_dyn_concat (guile_buffer_output,
+                                   ptr_data,
+                                   ptr_newline - ptr_data);
         weechat_guile_output_flush ();
-        ptr_newline[0] = '\n';
         ptr_data = ++ptr_newline;
     }
-    weechat_string_dyn_concat (guile_buffer_output, ptr_data);
+    weechat_string_dyn_concat (guile_buffer_output, ptr_data, -1);
+
+    free (data2);
 }
 #endif
 
