@@ -1,7 +1,7 @@
 /*
  * irc-bar-item.c - bar items for IRC plugin
  *
- * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -114,7 +114,7 @@ irc_bar_item_buffer_plugin (const void *pointer, void *data,
 char *
 irc_bar_item_buffer_name_content (struct t_gui_buffer *buffer, int short_name)
 {
-    char buf[512], buf_name[256], modes[128];
+    char buf[512], buf_name[256];
     const char *name, *localvar_type;
     int part_from_channel, display_server, is_channel;
     struct t_irc_server *server;
@@ -124,7 +124,6 @@ irc_bar_item_buffer_name_content (struct t_gui_buffer *buffer, int short_name)
         return NULL;
 
     buf_name[0] = '\0';
-    modes[0] = '\0';
 
     display_server = (weechat_config_integer (irc_config_look_item_display_server) == IRC_CONFIG_LOOK_ITEM_DISPLAY_SERVER_NAME);
 
@@ -187,10 +186,10 @@ irc_bar_item_buffer_name_content (struct t_gui_buffer *buffer, int short_name)
         }
     }
 
-    snprintf (buf, sizeof (buf), "%s%s%s",
+    snprintf (buf, sizeof (buf),
+              "%s%s",
               (server && server->ssl_connected) ? IRC_COLOR_STATUS_NAME_SSL : IRC_COLOR_STATUS_NAME,
-              buf_name,
-              modes);
+              buf_name);
 
     return strdup (buf);
 }
@@ -379,6 +378,106 @@ irc_bar_item_channel (const void *pointer, void *data,
     return strdup (buf);
 }
 
+/*
+ * Returns content of bar item "irc_nick": bar item with nick name
+ * (without modes).
+ */
+
+char *
+irc_bar_item_nick (const void *pointer, void *data,
+                   struct t_gui_bar_item *item,
+                   struct t_gui_window *window, struct t_gui_buffer *buffer,
+                   struct t_hashtable *extra_info)
+{
+    char buf[512];
+    struct t_irc_server *server;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
+    if (!buffer)
+        return NULL;
+
+    irc_buffer_get_server_and_channel (buffer, &server, NULL);
+    if (!server || !server->nick)
+        return NULL;
+
+    snprintf (buf, sizeof (buf), "%s%s",
+              IRC_COLOR_INPUT_NICK,
+              server->nick);
+
+    return strdup (buf);
+}
+
+/*
+ * Returns content of bar item "irc_host": bar item with self host.
+ */
+
+char *
+irc_bar_item_host (const void *pointer, void *data,
+                   struct t_gui_bar_item *item,
+                   struct t_gui_window *window, struct t_gui_buffer *buffer,
+                   struct t_hashtable *extra_info)
+{
+    struct t_irc_server *server;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
+    if (!buffer)
+        return NULL;
+
+    irc_buffer_get_server_and_channel (buffer, &server, NULL);
+    if (!server || !server->host)
+        return NULL;
+
+    return strdup (server->host);
+}
+
+/*
+ * Returns content of bar item "irc_nick_host": bar item with nick and host.
+ */
+
+char *
+irc_bar_item_nick_host (const void *pointer, void *data,
+                        struct t_gui_bar_item *item,
+                        struct t_gui_window *window,
+                        struct t_gui_buffer *buffer,
+                        struct t_hashtable *extra_info)
+{
+    char buf[512];
+    struct t_irc_server *server;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) item;
+    (void) window;
+    (void) extra_info;
+
+    if (!buffer)
+        return NULL;
+
+    irc_buffer_get_server_and_channel (buffer, &server, NULL);
+    if (!server || !server->nick)
+        return NULL;
+
+    snprintf (buf, sizeof (buf), "%s%s%s",
+              server->nick,
+              (server->host) ? "@" : "",
+              (server->host) ? server->host : "");
+
+    return strdup (buf);
+}
+
 /*
  * Returns content of bar item "lag": bar item with lag value.
  */
@@ -557,6 +656,7 @@ irc_bar_item_focus_buffer_nicklist (const void *pointer, void *data,
     struct t_gui_buffer *buffer;
     struct t_irc_nick *ptr_nick;
     const char *str_buffer, *nick;
+    char str_value[128];
 
     str_buffer = weechat_hashtable_get (info, "_buffer");
     if (!str_buffer || !str_buffer[0])
@@ -580,9 +680,15 @@ irc_bar_item_focus_buffer_nicklist (const void *pointer, void *data,
         if (nick)
         {
             ptr_nick = irc_nick_search (ptr_server, ptr_channel, nick);
-            if (ptr_nick && ptr_nick->host)
+            if (ptr_nick)
             {
-                weechat_hashtable_set (info, "irc_host", ptr_nick->host);
+                snprintf (str_value, sizeof (str_value),
+                          "0x%lx", (unsigned long)ptr_nick);
+                weechat_hashtable_set (info, "irc_nick", str_value);
+
+                if (ptr_nick->host)
+                    weechat_hashtable_set (info, "irc_host", ptr_nick->host);
+
                 return info;
             }
         }
@@ -615,6 +721,9 @@ irc_bar_item_buffer_switch (const void *pointer, void *data,
     weechat_bar_item_update ("lag");
     weechat_bar_item_update ("input_prompt");
     weechat_bar_item_update ("irc_nick_modes");
+    weechat_bar_item_update ("irc_nick");
+    weechat_bar_item_update ("irc_host");
+    weechat_bar_item_update ("irc_nick_host");
 
     return WEECHAT_RC_OK;
 }
@@ -648,6 +757,12 @@ irc_bar_item_init ()
                           &irc_bar_item_buffer_modes, NULL, NULL);
     weechat_bar_item_new ("irc_channel",
                           &irc_bar_item_channel, NULL, NULL);
+    weechat_bar_item_new ("irc_nick",
+                          &irc_bar_item_nick, NULL, NULL);
+    weechat_bar_item_new ("irc_host",
+                          &irc_bar_item_host, NULL, NULL);
+    weechat_bar_item_new ("irc_nick_host",
+                          &irc_bar_item_nick_host, NULL, NULL);
     weechat_bar_item_new ("lag",
                           &irc_bar_item_lag, NULL, NULL);
     weechat_bar_item_new ("input_prompt",
