@@ -40,6 +40,10 @@
 #include "irc-input.h"
 
 
+/* default CHANTYPES */
+char *irc_channel_default_chantypes = "#&";
+
+
 /*
  * Checks if a channel pointer is valid for a server.
  *
@@ -247,6 +251,18 @@ irc_channel_create_buffer (struct t_irc_server *server,
 
     ptr_buffer = irc_channel_search_buffer (server, channel_type,
                                             channel_name);
+    if (!ptr_buffer && (channel_type == IRC_CHANNEL_TYPE_PRIVATE))
+    {
+        /*
+         * in case of private buffer, we reuse a buffer which has wrong type
+         * "channel" (opened by a manual /join or autojoin)
+         */
+        ptr_buffer = irc_channel_search_buffer (server,
+                                                IRC_CHANNEL_TYPE_CHANNEL,
+                                                channel_name);
+        if (ptr_buffer)
+            weechat_bar_item_update ("buffer_name");
+    }
     if (ptr_buffer)
     {
         weechat_nicklist_remove_all (ptr_buffer);
@@ -659,7 +675,7 @@ irc_channel_is_channel (struct t_irc_server *server, const char *string)
     first_char[1] = '\0';
     return (strpbrk (first_char,
                      (server && server->chantypes) ?
-                     server->chantypes : IRC_CHANNEL_DEFAULT_CHANTYPES)) ?
+                     server->chantypes : irc_channel_default_chantypes)) ?
         1 : 0;
 }
 
@@ -1146,8 +1162,8 @@ void
 irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
                                         const char *nick)
 {
-    int i, unmask_delay, length_tags, nick_found, join, chghost;
-    int nick_changed, smart_filtered, remove_smart_filter;
+    int i, unmask_delay, length_tags, nick_found, join, account;
+    int chghost, nick_changed, smart_filtered, remove_smart_filter;
     time_t *ptr_time, date_min;
     struct t_hdata *hdata_line, *hdata_line_data;
     struct t_gui_line *own_lines;
@@ -1223,6 +1239,7 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
             length_tags = 0;
             nick_found = 0;
             join = 0;
+            account = 0;
             chghost = 0;
             nick_changed = 0;
             irc_nick1 = NULL;
@@ -1237,6 +1254,8 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
                 }
                 else if (strcmp (tags[i], "irc_join") == 0)
                     join = 1;
+                else if (strcmp (tags[i], "irc_account") == 0)
+                    account = 1;
                 else if (strcmp (tags[i], "irc_chghost") == 0)
                     chghost = 1;
                 else if (strcmp (tags[i], "irc_nick") == 0)
@@ -1262,7 +1281,7 @@ irc_channel_join_smart_filtered_unmask (struct t_irc_channel *channel,
                     break;
                 remove_smart_filter = 1;
             }
-            else if (nick_found && (join || chghost) && smart_filtered)
+            else if (nick_found && (join || account || chghost) && smart_filtered)
             {
                 remove_smart_filter = 1;
             }
