@@ -138,6 +138,7 @@ extern struct t_config_option *irc_config_look_pv_tags;
 extern struct t_config_option *irc_config_look_raw_messages;
 extern struct t_config_option *irc_config_look_server_buffer;
 extern struct t_config_option *irc_config_look_smart_filter;
+extern struct t_config_option *irc_config_look_smart_filter_account;
 extern struct t_config_option *irc_config_look_smart_filter_chghost;
 extern struct t_config_option *irc_config_look_smart_filter_delay;
 extern struct t_config_option *irc_config_look_smart_filter_join;
@@ -153,6 +154,7 @@ extern struct t_config_option *irc_config_color_item_channel_modes;
 extern struct t_config_option *irc_config_color_item_lag_counting;
 extern struct t_config_option *irc_config_color_item_lag_finished;
 extern struct t_config_option *irc_config_color_item_nick_modes;
+extern struct t_config_option *irc_config_color_message_account;
 extern struct t_config_option *irc_config_color_message_chghost;
 extern struct t_config_option *irc_config_color_message_join;
 extern struct t_config_option *irc_config_color_message_kick;
