@@ -1,7 +1,7 @@
 /*
  * irc-message.c - functions for IRC messages
  *
- * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -446,7 +446,6 @@ irc_message_convert_charset (const char *message, int pos_start,
     return msg_result;
 }
 
-
 /*
  * Gets nick from host in an IRC message.
  */
@@ -759,6 +758,62 @@ irc_message_split_string (struct t_hashtable *hashtable,
     return 1;
 }
 
+/*
+ * Splits a AUTHENTICATE message: in 400-byte chunks, and adds an extra
+ * message "AUTHENTICATE +" if the last message has exactly 400 bytes.
+ *
+ * Returns:
+ *   1: OK
+ *   0: error
+ */
+
+int
+irc_message_split_authenticate (struct t_hashtable *hashtable,
+                                const char *tags, const char *host,
+                                const char *command, const char *arguments)
+{
+    int number, length;
+    char message[8192], *args;
+    const char *ptr_args;
+
+    number = 1;
+
+    length = 0;
+    ptr_args = arguments;
+    while (ptr_args && ptr_args[0])
+    {
+        length = strlen (ptr_args);
+        if (length == 0)
+            break;
+        if (length > 400)
+            length = 400;
+        args = weechat_strndup (ptr_args, length);
+        if (!args)
+            return 0;
+        snprintf (message, sizeof (message), "%s%s%s %s",
+                  (host) ? host : "",
+                  (host) ? " " : "",
+                  command,
+                  args);
+        irc_message_split_add (hashtable, number, tags, message, args);
+        free (args);
+        number++;
+        ptr_args += length;
+    }
+
+    if ((length == 0) || (length == 400))
+    {
+        snprintf (message, sizeof (message), "%s%s%s +",
+                  (host) ? host : "",
+                  (host) ? " " : "",
+                  command);
+        irc_message_split_add (hashtable, number, tags, message, "+");
+        number++;
+    }
+
+    return 1;
+}
+
 /*
  * Splits a JOIN message, taking care of keeping channel keys with channel
  * names.
@@ -896,12 +951,14 @@ irc_message_split_join (struct t_hashtable *hashtable,
 
 int
 irc_message_split_privmsg_notice (struct t_hashtable *hashtable,
-                                  char *tags, char *host, char *command,
-                                  char *target, char *arguments,
+                                  const char *tags, const char *host,
+                                  const char *command, const char *target,
+                                  const char *arguments,
                                   int max_length_nick_user_host,
                                   int max_length)
 {
-    char prefix[4096], suffix[2], *pos, saved_char;
+    char *arguments2, prefix[4096], suffix[2], *pos, saved_char;
+    const char *ptr_args;
     int length, rc;
 
     /*
@@ -912,23 +969,29 @@ irc_message_split_privmsg_notice (struct t_hashtable *hashtable,
      *   :nick!user@host.com PRIVMSG #channel :hello world!
      */
 
+    arguments2 = strdup (arguments);
+    if (!arguments2)
+        return 0;
+
+    ptr_args = arguments2;
+
     /* for CTCP, prefix will be ":\01xxxx " and suffix "\01" */
     prefix[0] = '\0';
     suffix[0] = '\0';
-    length = strlen (arguments);
-    if ((arguments[0] == '\01')
-        && (arguments[length - 1] == '\01'))
+    length = strlen (arguments2);
+    if ((arguments2[0] == '\01')
+        && (arguments2[length - 1] == '\01'))
     {
-        pos = strchr (arguments, ' ');
+        pos = strchr (arguments2, ' ');
         if (pos)
         {
             pos++;
             saved_char = pos[0];
             pos[0] = '\0';
-            snprintf (prefix, sizeof (prefix), ":%s", arguments);
+            snprintf (prefix, sizeof (prefix), ":%s", arguments2);
             pos[0] = saved_char;
-            arguments[length - 1] = '\0';
-            arguments = pos;
+            arguments2[length - 1] = '\0';
+            ptr_args = pos;
             suffix[0] = '\01';
             suffix[1] = '\0';
         }
@@ -937,9 +1000,11 @@ irc_message_split_privmsg_notice (struct t_hashtable *hashtable,
         strcpy (prefix, ":");
 
     rc = irc_message_split_string (hashtable, tags, host, command, target,
-                                   prefix, arguments, suffix,
+                                   prefix, ptr_args, suffix,
                                    ' ', max_length_nick_user_host, max_length);
 
+    free (arguments2);
+
     return rc;
 }
 
@@ -953,8 +1018,9 @@ irc_message_split_privmsg_notice (struct t_hashtable *hashtable,
 
 int
 irc_message_split_005 (struct t_hashtable *hashtable,
-                       char *tags, char *host, char *command, char *target,
-                       char *arguments, int max_length)
+                       const char *tags, const char *host, const char *command,
+                       const char *target, const char *arguments,
+                       int max_length)
 {
     char *pos, suffix[4096];
 
@@ -1114,7 +1180,13 @@ irc_message_split (struct t_irc_server *server, const char *message)
         max_length_host +            /* host */
         1;                           /* " "  */
 
-    if ((weechat_strcasecmp (command, "ison") == 0)
+    if (weechat_strcasecmp (command, "authenticate") == 0)
+    {
+        /* AUTHENTICATE UzXAmVffxuzFy77XWBGwABBQAgdinelBrKZaR3wE7nsIETuTVY= */
+        split_ok = irc_message_split_authenticate (
+            hashtable, tags, host, command, arguments);
+    }
+    else if ((weechat_strcasecmp (command, "ison") == 0)
         || (weechat_strcasecmp (command, "wallops") == 0))
     {
         /*
