@@ -59,6 +59,7 @@ PHP_FUNCTION(weechat_string_has_highlight);
 PHP_FUNCTION(weechat_string_has_highlight_regex);
 PHP_FUNCTION(weechat_string_mask_to_regex);
 PHP_FUNCTION(weechat_string_format_size);
+PHP_FUNCTION(weechat_string_color_code_size);
 PHP_FUNCTION(weechat_string_remove_color);
 PHP_FUNCTION(weechat_string_is_command_char);
 PHP_FUNCTION(weechat_string_input_for_buffer);
@@ -198,6 +199,11 @@ PHP_FUNCTION(weechat_bar_update);
 PHP_FUNCTION(weechat_bar_remove);
 PHP_FUNCTION(weechat_command);
 PHP_FUNCTION(weechat_command_options);
+PHP_FUNCTION(weechat_completion_new);
+PHP_FUNCTION(weechat_completion_search);
+PHP_FUNCTION(weechat_completion_get_string);
+PHP_FUNCTION(weechat_completion_list_add);
+PHP_FUNCTION(weechat_completion_free);
 PHP_FUNCTION(weechat_info_get);
 PHP_FUNCTION(weechat_info_get_hashtable);
 PHP_FUNCTION(weechat_infolist_new);
