@@ -112,6 +112,7 @@ const zend_function_entry weechat_functions[] = {
     PHP_FE(weechat_string_has_highlight_regex, NULL)
     PHP_FE(weechat_string_mask_to_regex, NULL)
     PHP_FE(weechat_string_format_size, NULL)
+    PHP_FE(weechat_string_color_code_size, NULL)
     PHP_FE(weechat_string_remove_color, NULL)
     PHP_FE(weechat_string_is_command_char, NULL)
     PHP_FE(weechat_string_input_for_buffer, NULL)
@@ -251,6 +252,11 @@ const zend_function_entry weechat_functions[] = {
     PHP_FE(weechat_bar_remove, NULL)
     PHP_FE(weechat_command, NULL)
     PHP_FE(weechat_command_options, NULL)
+    PHP_FE(weechat_completion_new, NULL)
+    PHP_FE(weechat_completion_search, NULL)
+    PHP_FE(weechat_completion_get_string, NULL)
+    PHP_FE(weechat_completion_list_add, NULL)
+    PHP_FE(weechat_completion_free, NULL)
     PHP_FE(weechat_info_get, NULL)
     PHP_FE(weechat_info_get_hashtable, NULL)
     PHP_FE(weechat_infolist_new, NULL)
