@@ -97,45 +97,6 @@ plugin_api_ngettext (const char *single, const char *plural, int count)
     return NG_(single, plural, count);
 }
 
-/*
- * Encodes a string in base 16, 32, or 64.
- */
-
-int
-plugin_api_string_base_encode (int base, const char *from, int length,
-                               char *to)
-{
-    switch (base)
-    {
-        case 16:
-            return string_base16_encode (from, length, to);
-        case 32:
-            return string_base32_encode (from, length, to);
-        case 64:
-            return string_base64_encode (from, length, to);
-    }
-    return -1;
-}
-
-/*
- * Decodes a string encoded in base 16, 32, or 64.
- */
-
-int
-plugin_api_string_base_decode (int base, const char *from, char *to)
-{
-    switch (base)
-    {
-        case 16:
-            return string_base16_decode (from, to);
-        case 32:
-            return string_base32_decode (from, to);
-        case 64:
-            return string_base64_decode (from, to);
-    }
-    return -1;
-}
-
 /*
  * Computes hash of data using the given algorithm.
  *
@@ -649,6 +610,9 @@ plugin_api_init ()
                 &gui_buffer_hdata_buffer_visited_cb, NULL, NULL);
     hook_hdata (NULL, "completion", N_("structure with completion"),
                 &gui_completion_hdata_completion_cb, NULL, NULL);
+    hook_hdata (NULL, "completion_word",
+                N_("structure with word found for a completion"),
+                &gui_completion_hdata_completion_word_cb, NULL, NULL);
     hook_hdata (NULL, "config_file", N_("config file"),
                 &config_file_hdata_config_file_cb, NULL, NULL);
     hook_hdata (NULL, "config_section", N_("config section"),
