@@ -1,7 +1,7 @@
 /*
  * script-api.c - script API functions, used by script plugins
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2012 Simon Arlott
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -17,7 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -47,6 +47,39 @@ plugin_script_api_charset_set (struct t_plugin_script *script,
     script->charset = (charset) ? strdup (charset) : NULL;
 }
 
+/*
+ * Checks if a string matches a list of masks.
+ *
+ * Returns:
+ *   1: string matches list of masks
+ *   0: string does not match list of masks
+ */
+
+int
+plugin_script_api_string_match_list (struct t_weechat_plugin *weechat_plugin,
+                                     const char *string, const char *masks,
+                                     int case_sensitive)
+{
+    char **list_masks;
+    int match;
+
+    list_masks = (masks && masks[0]) ?
+        weechat_string_split (masks, ",", NULL,
+                              WEECHAT_STRING_SPLIT_STRIP_LEFT
+                              | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                              | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                              0, NULL) : NULL;
+
+    match = weechat_string_match_list (string,
+                                       (const char **)list_masks,
+                                       case_sensitive);
+
+    if (list_masks)
+        weechat_string_free_split (list_masks);
+
+    return match;
+}
+
 /*
  * Creates a new configuration file.
  *
@@ -968,10 +1001,10 @@ plugin_script_api_hook_info (struct t_weechat_plugin *weechat_plugin,
                              const char *info_name,
                              const char *description,
                              const char *args_description,
-                             const char *(*callback)(const void *pointer,
-                                                     void *data,
-                                                     const char *info_name,
-                                                     const char *arguments),
+                             char *(*callback)(const void *pointer,
+                                               void *data,
+                                               const char *info_name,
+                                               const char *arguments),
                              const char *function,
                              const char *data)
 {
@@ -1249,6 +1282,33 @@ plugin_script_api_bar_item_new (struct t_weechat_plugin *weechat_plugin,
     return new_item;
 }
 
+/*
+ * Executes a command on a buffer (simulates user entry) with options.
+ */
+
+int
+plugin_script_api_command_options (struct t_weechat_plugin *weechat_plugin,
+                                   struct t_plugin_script *script,
+                                   struct t_gui_buffer *buffer,
+                                   const char *command,
+                                   struct t_hashtable *options)
+{
+    char *command2;
+    int rc;
+
+    command2 = (script && script->charset && script->charset[0]) ?
+        weechat_iconv_to_internal (script->charset, command) : NULL;
+
+    rc = weechat_command_options (buffer,
+                                  (command2) ? command2 : command,
+                                  options);
+
+    if (command2)
+        free (command2);
+
+    return rc;
+}
+
 /*
  * Executes a command on a buffer (simulates user entry).
  */
@@ -1258,18 +1318,8 @@ plugin_script_api_command (struct t_weechat_plugin *weechat_plugin,
                            struct t_plugin_script *script,
                            struct t_gui_buffer *buffer, const char *command)
 {
-    char *command2;
-    int rc;
-
-    command2 = (script && script->charset && script->charset[0]) ?
-        weechat_iconv_to_internal (script->charset, command) : NULL;
-
-    rc = weechat_command (buffer, (command2) ? command2 : command);
-
-    if (command2)
-        free (command2);
-
-    return rc;
+    return plugin_script_api_command_options (weechat_plugin, script, buffer,
+                                              command, NULL);
 }
 
 /*
