@@ -55,6 +55,7 @@
 #include "../gui/gui-buffer.h"
 #include "../gui/gui-chat.h"
 #include "../gui/gui-color.h"
+#include "../gui/gui-completion.h"
 #include "../gui/gui-key.h"
 #include "../gui/gui-nicklist.h"
 #include "../gui/gui-window.h"
@@ -631,9 +632,10 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->string_split_command = &string_split_command;
         new_plugin->string_free_split_command = &string_free_split_command;
         new_plugin->string_format_size = &string_format_size;
+        new_plugin->string_color_code_size = &gui_color_code_size;
         new_plugin->string_remove_color = &gui_color_decode;
-        new_plugin->string_base_encode = &plugin_api_string_base_encode;
-        new_plugin->string_base_decode = &plugin_api_string_base_decode;
+        new_plugin->string_base_encode = &string_base_encode;
+        new_plugin->string_base_decode = &string_base_decode;
         new_plugin->string_hex_dump = &string_hex_dump;
         new_plugin->string_is_command_char = &string_is_command_char;
         new_plugin->string_input_for_buffer = &string_input_for_buffer;
@@ -785,8 +787,8 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->hook_hsignal_send = &hook_hsignal_send;
         new_plugin->hook_config = &hook_config;
         new_plugin->hook_completion = &hook_completion;
-        new_plugin->hook_completion_get_string = &hook_completion_get_string;
-        new_plugin->hook_completion_list_add = &hook_completion_list_add;
+        new_plugin->hook_completion_get_string = &gui_completion_get_string;
+        new_plugin->hook_completion_list_add = &gui_completion_list_add;
         new_plugin->hook_modifier = &hook_modifier;
         new_plugin->hook_modifier_exec = &hook_modifier_exec;
         new_plugin->hook_info = &hook_info;
@@ -849,6 +851,12 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->command = &plugin_api_command;
         new_plugin->command_options = &plugin_api_command_options;
 
+        new_plugin->completion_new = &gui_completion_new;
+        new_plugin->completion_search = &gui_completion_search;
+        new_plugin->completion_get_string = &gui_completion_get_string;
+        new_plugin->completion_list_add = &gui_completion_list_add;
+        new_plugin->completion_free = &gui_completion_free;
+
         new_plugin->network_pass_proxy = &network_pass_proxy;
         new_plugin->network_connect_to = &network_connect_to;
 
@@ -1133,6 +1141,9 @@ plugin_remove (struct t_weechat_plugin *plugin)
     struct t_weechat_plugin *new_weechat_plugins;
     struct t_gui_buffer *ptr_buffer, *next_buffer;
 
+    /* remove all completions (only those created by API) */
+    gui_completion_free_all_plugin (plugin);
+
     /* close buffers created by this plugin */
     ptr_buffer = gui_buffers;
     while (ptr_buffer)
