@@ -234,13 +234,31 @@ weechat_python_hashtable_map_cb (void *data,
 
     dict = (PyObject *)data;
 
-    dict_key = Py_BuildValue ("s", key);
-    dict_value = Py_BuildValue ("s", value);
+#if PY_MAJOR_VERSION >= 3
+    /* key */
+    if (weechat_utf8_is_valid (key, -1, NULL))
+        dict_key = Py_BuildValue ("s", key);  /* Python 3: str */
+    else
+        dict_key = Py_BuildValue ("y", key);  /* Python 3: bytes */
+    /* value */
+    if (weechat_utf8_is_valid (value, -1, NULL))
+        dict_value = Py_BuildValue ("s", value);  /* Python 3: str */
+    else
+        dict_value = Py_BuildValue ("y", value);  /* Python 3: bytes */
+#else
+    /* key */
+    dict_key = Py_BuildValue ("s", key);  /* Python 2: str */
+    /* value */
+    dict_value = Py_BuildValue ("s", value);  /* Python 2: str */
+#endif
 
-    PyDict_SetItem (dict, dict_key, dict_value);
+    if (dict_key && dict_value)
+        PyDict_SetItem (dict, dict_key, dict_value);
 
-    Py_DECREF (dict_key);
-    Py_DECREF (dict_value);
+    if (dict_key)
+        Py_DECREF (dict_key);
+    if (dict_value)
+        Py_DECREF (dict_value);
 }
 
 /*
@@ -426,13 +444,13 @@ weechat_python_output (PyObject *self, PyObject *args)
         ptr_msg = msg;
         while ((ptr_newline = strchr (ptr_msg, '\n')) != NULL)
         {
-            ptr_newline[0] = '\0';
-            weechat_string_dyn_concat (python_buffer_output, ptr_msg);
+            weechat_string_dyn_concat (python_buffer_output,
+                                       ptr_msg,
+                                       ptr_newline - ptr_msg);
             weechat_python_output_flush ();
-            ptr_newline[0] = '\n';
             ptr_msg = ++ptr_newline;
         }
-        weechat_string_dyn_concat (python_buffer_output, ptr_msg);
+        weechat_string_dyn_concat (python_buffer_output, ptr_msg, -1);
     }
 
     Py_INCREF(Py_None);
@@ -779,8 +797,8 @@ weechat_python_load (const char *filename, const char *code)
 #endif /* PY_MAJOR_VERSION >= 3 */
     FILE *fp;
     PyObject *python_path, *path, *module_main, *globals, *rc;
-    char *weechat_home;
-    char *str_home;
+    char *weechat_sharedir, *weechat_home;
+    char *str_sharedir, *str_home;
     int len;
 
     fp = NULL;
@@ -844,8 +862,34 @@ weechat_python_load (const char *filename, const char *code)
 
     PyThreadState_Swap (python_current_interpreter);
 
-    /* adding $weechat_dir/python in $PYTHONPATH */
+    /* adding $weechat_sharedir/python in $PYTHONPATH */
     python_path = PySys_GetObject ("path");
+    weechat_sharedir = weechat_info_get ("weechat_sharedir", "");
+    if (weechat_sharedir)
+    {
+        len = strlen (weechat_sharedir) + 1 + strlen (PYTHON_PLUGIN_NAME) + 1;
+        str_sharedir = malloc (len);
+        if (str_sharedir)
+        {
+            snprintf (str_sharedir, len, "%s/python", weechat_sharedir);
+#if PY_MAJOR_VERSION >= 3
+            /* python >= 3.x */
+            path = PyUnicode_FromString (str_sharedir);
+#else
+            /* python <= 2.x */
+            path = PyBytes_FromString (str_sharedir);
+#endif /* PY_MAJOR_VERSION >= 3 */
+            if (path != NULL)
+            {
+                PyList_Insert (python_path, 0, path);
+                Py_DECREF (path);
+            }
+            free (str_sharedir);
+        }
+        free (weechat_sharedir);
+    }
+
+    /* adding $weechat_dir/python in $PYTHONPATH */
     weechat_home = weechat_info_get ("weechat_dir", "");
     if (weechat_home)
     {
@@ -871,6 +915,7 @@ weechat_python_load (const char *filename, const char *code)
         free (weechat_home);
     }
 
+
     weechat_python_set_output ();
 
     python_current_script_filename = filename;
