@@ -22,9 +22,7 @@
 
 #include <time.h>
 
-#ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
-#endif /* HAVE_GNUTLS */
 
 struct t_relay_server;
 
@@ -92,11 +90,9 @@ struct t_relay_client
     int sock;                          /* socket for connection             */
     int server_port;                   /* port used for connection          */
     int ssl;                           /* 1 if SSL is enabled               */
-#ifdef HAVE_GNUTLS
     gnutls_session_t gnutls_sess;      /* gnutls session (only if SSL used) */
     struct t_hook *hook_timer_handshake; /* timer for doing gnutls handshake*/
     int gnutls_handshake_ok;           /* 1 if handshake was done and OK    */
-#endif /* HAVE_GNUTLS */
     int websocket;                     /* 0=not a ws, 1=init ws, 2=ws ready */
     struct t_hashtable *http_headers;  /* HTTP headers for websocket        */
     char *address;                     /* string with IP address            */
@@ -106,10 +102,14 @@ struct t_relay_client
     char *protocol_string;             /* example: "ipv6.ssl.irc.freenode"  */
     char *protocol_args;               /* arguments used for protocol       */
                                        /* example: server for irc protocol  */
+    char *nonce;                       /* nonce used in salt of hashed pwd  */
+    int password_hash_algo;            /* password hash algo (negotiated)   */
+    int password_hash_iterations;      /* password hash iterations          */
     time_t listen_start_time;          /* when listening started            */
     time_t start_time;                 /* time of client connection         */
     time_t end_time;                   /* time of client disconnection      */
     struct t_hook *hook_fd;            /* hook for socket or child pipe     */
+    struct t_hook *hook_timer_send;    /* timer to quickly flush outqueue   */
     time_t last_activity;              /* time of last byte received/sent   */
     unsigned long long bytes_recv;     /* bytes received from client        */
     unsigned long long bytes_sent;     /* bytes sent to client              */
@@ -124,6 +124,7 @@ struct t_relay_client
 };
 
 extern char *relay_client_status_string[];
+extern char *relay_client_status_name[];
 extern char *relay_client_msg_type_string[];
 extern struct t_relay_client *relay_clients;
 extern struct t_relay_client *last_relay_client;
