@@ -32,11 +32,11 @@
 #include "../weechat-plugin.h"
 #include "relay.h"
 #include "relay-config.h"
-#include "irc/relay-irc.h"
 #include "relay-client.h"
 #include "relay-buffer.h"
 #include "relay-network.h"
 #include "relay-server.h"
+#include "irc/relay-irc.h"
 
 
 struct t_config_file *relay_config_file = NULL;
@@ -60,12 +60,16 @@ struct t_config_option *relay_config_color_text_selected;
 
 struct t_config_option *relay_config_network_allow_empty_password;
 struct t_config_option *relay_config_network_allowed_ips;
+struct t_config_option *relay_config_network_auth_timeout;
 struct t_config_option *relay_config_network_bind_address;
 struct t_config_option *relay_config_network_clients_purge_delay;
 struct t_config_option *relay_config_network_compression_level;
 struct t_config_option *relay_config_network_ipv6;
 struct t_config_option *relay_config_network_max_clients;
+struct t_config_option *relay_config_network_nonce_size;
 struct t_config_option *relay_config_network_password;
+struct t_config_option *relay_config_network_password_hash_algo;
+struct t_config_option *relay_config_network_password_hash_iterations;
 struct t_config_option *relay_config_network_ssl_cert_key;
 struct t_config_option *relay_config_network_ssl_priorities;
 struct t_config_option *relay_config_network_totp_secret;
@@ -90,6 +94,7 @@ struct t_config_option *relay_config_weechat_commands;
 regex_t *relay_config_regex_allowed_ips = NULL;
 regex_t *relay_config_regex_websocket_allowed_origins = NULL;
 struct t_hashtable *relay_config_hashtable_irc_backlog_tags = NULL;
+char **relay_config_network_password_hash_algo_list = NULL;
 
 
 /*
@@ -148,6 +153,37 @@ relay_config_change_network_allowed_ips (const void *pointer, void *data,
     }
 }
 
+/*
+ * Callback for changes on option "relay.network.password_hash_algo".
+ */
+
+void
+relay_config_change_network_password_hash_algo (const void *pointer,
+                                                void *data,
+                                                struct t_config_option *option)
+{
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+    (void) option;
+
+    if (relay_config_network_password_hash_algo_list)
+    {
+        weechat_string_free_split (relay_config_network_password_hash_algo_list);
+        relay_config_network_password_hash_algo_list = NULL;
+    }
+
+    relay_config_network_password_hash_algo_list = weechat_string_split (
+        weechat_config_string (relay_config_network_password_hash_algo),
+        ",",
+        NULL,
+        WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+        0,
+        NULL);
+}
+
 /*
  * Callback for changes on option "relay.network.bind_address".
  */
@@ -282,7 +318,6 @@ relay_config_check_network_ssl_priorities (const void *pointer, void *data,
                                            struct t_config_option *option,
                                            const char *value)
 {
-#ifdef HAVE_GNUTLS
     gnutls_priority_t priority_cache;
     const char *pos_error;
     int rc;
@@ -311,15 +346,6 @@ relay_config_check_network_ssl_priorities (const void *pointer, void *data,
                     (pos_error) ? pos_error : value);
 
     return 0;
-#else
-    /* make C compiler happy */
-    (void) pointer;
-    (void) data;
-    (void) option;
-    (void) value;
-
-    return 1;
-#endif /* HAVE_GNUTLS */
 }
 
 /*
@@ -335,13 +361,11 @@ relay_config_change_network_ssl_priorities (const void *pointer, void *data,
     (void) data;
     (void) option;
 
-#ifdef HAVE_GNUTLS
     if (relay_network_init_ok && relay_gnutls_priority_cache)
     {
         gnutls_priority_deinit (*relay_gnutls_priority_cache);
         relay_network_set_priority ();
     }
-#endif /* HAVE_GNUTLS */
 }
 
 /*
@@ -726,17 +750,6 @@ relay_config_create_option_port_path (const void *pointer, void *data,
     relay_server_get_protocol_args (option_name, &ipv4, &ipv6, &ssl,
                                     &unix_socket, &protocol, &protocol_args);
 
-#ifndef HAVE_GNUTLS
-    if (ssl)
-    {
-        weechat_printf (NULL,
-                        _("%s%s: cannot use SSL because WeeChat was not built "
-                          "with GnuTLS support"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME);
-        rc = WEECHAT_CONFIG_OPTION_SET_ERROR;
-    }
-#endif /* HAVE_GNUTLS */
-
     if (rc != WEECHAT_CONFIG_OPTION_SET_ERROR)
     {
         if (protocol)
@@ -937,7 +950,7 @@ relay_config_init ()
         relay_config_file, ptr_section,
         "status_active", "color",
         N_("text color for \"connected\" status"),
-        NULL, 0, 0, "lightblue", NULL, 0,
+        NULL, 0, 0, "green", NULL, 0,
         NULL, NULL, NULL,
         &relay_config_refresh_cb, NULL, NULL,
         NULL, NULL, NULL);
@@ -945,7 +958,7 @@ relay_config_init ()
         relay_config_file, ptr_section,
         "status_auth_failed", "color",
         N_("text color for \"authentication failed\" status"),
-        NULL, 0, 0, "lightred", NULL, 0,
+        NULL, 0, 0, "lightmagenta", NULL, 0,
         NULL, NULL, NULL,
         &relay_config_refresh_cb, NULL, NULL,
         NULL, NULL, NULL);
@@ -953,7 +966,7 @@ relay_config_init ()
         relay_config_file, ptr_section,
         "status_connecting", "color",
         N_("text color for \"connecting\" status"),
-        NULL, 0, 0, "yellow", NULL, 0,
+        NULL, 0, 0, "white", NULL, 0,
         NULL, NULL, NULL,
         &relay_config_refresh_cb, NULL, NULL,
         NULL, NULL, NULL);
@@ -969,7 +982,7 @@ relay_config_init ()
         relay_config_file, ptr_section,
         "status_waiting_auth", "color",
         N_("text color for \"waiting authentication\" status"),
-        NULL, 0, 0, "brown", NULL, 0,
+        NULL, 0, 0, "yellow", NULL, 0,
         NULL, NULL, NULL,
         &relay_config_refresh_cb, NULL, NULL,
         NULL, NULL, NULL);
@@ -1031,6 +1044,15 @@ relay_config_init ()
         NULL, NULL, NULL,
         &relay_config_change_network_allowed_ips, NULL, NULL,
         NULL, NULL, NULL);
+    relay_config_network_auth_timeout = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "auth_timeout", "integer",
+        N_("timeout (in seconds) for client authentication: connection is "
+           "closed if the client is still not authenticated after this delay "
+           "and the client status is set to \"authentication failed\" "
+           "(0 = wait forever)"),
+        NULL, 0, INT_MAX, "60", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     relay_config_network_bind_address = weechat_config_new_option (
         relay_config_file, ptr_section,
         "bind_address", "string",
@@ -1072,6 +1094,15 @@ relay_config_init ()
         N_("maximum number of clients connecting to a port (0 = no limit)"),
         NULL, 0, INT_MAX, "5", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+    relay_config_network_nonce_size = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "nonce_size", "integer",
+        N_("size of nonce (in bytes), generated when a client connects; "
+           "the client must use this nonce, concatenated to the client nonce "
+           "and the password when hashing the password in the \"init\" "
+           "command of the weechat protocol"),
+        NULL, 8, 128, "16", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     relay_config_network_password = weechat_config_new_option (
         relay_config_file, ptr_section,
         "password", "string",
@@ -1081,6 +1112,30 @@ relay_config_init ()
            "see /help eval)"),
         NULL, 0, 0, "", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+    relay_config_network_password_hash_algo = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "password_hash_algo", "string",
+        N_("comma separated list of hash algorithms used for password "
+           "authentication in weechat protocol, among these values: \"plain\" "
+           "(password in plain text, not hashed), \"sha256\", \"sha512\", "
+           "\"pbkdf2+sha256\", \"pbkdf2+sha512\"), \"*\" means all algorithms, "
+           "a name beginning with \"!\" is a negative value to prevent an "
+           "algorithm from being used, wildcard \"*\" is allowed in names "
+           "(examples: \"*\", \"pbkdf2*\", \"*,!plain\")"),
+        NULL, 0, 0, "*", NULL, 0,
+        NULL, NULL, NULL,
+        &relay_config_change_network_password_hash_algo, NULL, NULL,
+        NULL, NULL, NULL);
+    relay_config_network_password_hash_iterations = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "password_hash_iterations", "integer",
+        N_("number of iterations asked to the client in weechat protocol "
+           "when a hashed password with algorithm PBKDF2 is used for "
+           "authentication; more iterations is better in term of security but "
+           "is slower to compute; this number should not be too high if your "
+           "CPU is slow"),
+        NULL, 1, 1000000, "100000", NULL, 0,
+        NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     relay_config_network_ssl_cert_key = weechat_config_new_option (
         relay_config_file, ptr_section,
         "ssl_cert_key", "string",
@@ -1159,14 +1214,14 @@ relay_config_init ()
         N_("maximum number of minutes in backlog per IRC channel "
            "(0 = unlimited, examples: 1440 = one day, 10080 = one week, "
            "43200 = one month, 525600 = one year)"),
-        NULL, 0, INT_MAX, "1440", NULL, 0,
+        NULL, 0, INT_MAX, "0", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     relay_config_irc_backlog_max_number = weechat_config_new_option (
         relay_config_file, ptr_section,
         "backlog_max_number", "integer",
         N_("maximum number of lines in backlog per IRC channel "
            "(0 = unlimited)"),
-        NULL, 0, INT_MAX, "256", NULL, 0,
+        NULL, 0, INT_MAX, "1024", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     relay_config_irc_backlog_since_last_disconnect = weechat_config_new_option (
         relay_config_file, ptr_section,
@@ -1284,6 +1339,7 @@ relay_config_read ()
     if (rc == WEECHAT_CONFIG_READ_OK)
     {
         relay_config_change_network_allowed_ips (NULL, NULL, NULL);
+        relay_config_change_network_password_hash_algo (NULL, NULL, NULL);
         relay_config_change_irc_backlog_tags (NULL, NULL, NULL);
     }
     return rc;
@@ -1327,4 +1383,10 @@ relay_config_free ()
         weechat_hashtable_free (relay_config_hashtable_irc_backlog_tags);
         relay_config_hashtable_irc_backlog_tags = NULL;
     }
+
+    if (relay_config_network_password_hash_algo_list)
+    {
+        weechat_string_free_split (relay_config_network_password_hash_algo_list);
+        relay_config_network_password_hash_algo_list = NULL;
+    }
 }
