@@ -39,12 +39,16 @@ extern struct t_config_option *relay_config_color_text_selected;
 
 extern struct t_config_option *relay_config_network_allow_empty_password;
 extern struct t_config_option *relay_config_network_allowed_ips;
+extern struct t_config_option *relay_config_network_auth_timeout;
 extern struct t_config_option *relay_config_network_bind_address;
 extern struct t_config_option *relay_config_network_clients_purge_delay;
 extern struct t_config_option *relay_config_network_compression_level;
 extern struct t_config_option *relay_config_network_ipv6;
 extern struct t_config_option *relay_config_network_max_clients;
+extern struct t_config_option *relay_config_network_nonce_size;
 extern struct t_config_option *relay_config_network_password;
+extern struct t_config_option *relay_config_network_password_hash_algo;
+extern struct t_config_option *relay_config_network_password_hash_iterations;
 extern struct t_config_option *relay_config_network_ssl_cert_key;
 extern struct t_config_option *relay_config_network_ssl_priorities;
 extern struct t_config_option *relay_config_network_totp_secret;
@@ -63,6 +67,7 @@ extern struct t_config_option *relay_config_weechat_commands;
 extern regex_t *relay_config_regex_allowed_ips;
 extern regex_t *relay_config_regex_websocket_allowed_origins;
 extern struct t_hashtable *relay_config_hashtable_irc_backlog_tags;
+extern char **relay_config_network_password_hash_algo_list;
 
 extern int relay_config_check_network_totp_secret (const void *pointer,
                                                    void *data,
