@@ -1,7 +1,7 @@
 /*
  * relay-info.c - info and infolist hooks for relay plugin
  *
- * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -32,14 +32,13 @@
  * Returns relay info "relay_client_count".
  */
 
-const char *
+char *
 relay_info_info_relay_client_count_cb (const void *pointer, void *data,
                                        const char *info_name,
                                        const char *arguments)
 {
-    static char str_count[32];
+    char str_count[32], **items;
     const char *ptr_count;
-    char **items;
     int count, protocol, status, num_items;
     struct t_relay_client *ptr_client;
 
@@ -54,7 +53,11 @@ relay_info_info_relay_client_count_cb (const void *pointer, void *data,
     protocol = -1;
     status = -1;
 
-    items = weechat_string_split (arguments, ",", 0, 0, &num_items);
+    items = weechat_string_split (arguments, ",", NULL,
+                                  WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                  | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                  | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                  0, &num_items);
     if (num_items > 2)
         goto end;
 
@@ -106,7 +109,7 @@ end:
     if (items)
         weechat_string_free_split (items);
 
-    return ptr_count;
+    return (ptr_count) ? strdup (ptr_count) : NULL;
 }
 
 /*
