@@ -21,9 +21,8 @@
 #define WEECHAT_PLUGIN_RELAY_SERVER_H
 
 #include <time.h>
-#ifdef HAVE_GNUTLS
+
 #define RELAY_SERVER_GNUTLS_DH_BITS 1024
-#endif /* HAVE_GNUTLS */
 
 struct t_relay_server
 {
