@@ -31,6 +31,7 @@
 #include "relay-weechat-nicklist.h"
 #include "../relay-buffer.h"
 #include "../relay-client.h"
+#include "../relay-auth.h"
 #include "../relay-config.h"
 #include "../relay-raw.h"
 
@@ -159,148 +160,168 @@ relay_weechat_protocol_is_sync (struct t_relay_client *ptr_client,
 }
 
 /*
- * Parses PBKDF2 parameters from string with format:
- *
- *   algorithm:salt:iterations:hash
- *
- * where:
- *
- *   algorithm is "sha256" or "sha512"
- *   salt is the salt in hexadecimal
- *   iterations it the number of iterations (≥ 1)
- *   hash is the hashed password with the parameters above, in hexadecimal
+ * Replies to a client handshake command.
  */
 
 void
-relay_weechat_protocol_parse_pbkdf2 (const char *parameters,
-                                     char **algorithm,
-                                     char **salt,
-                                     int *salt_size,
-                                     int *iterations,
-                                     char **hash_pbkdf2)
+relay_weechat_protocol_handshake_reply (struct t_relay_client *client,
+                                        const char *id)
 {
-    char **argv, *error;
-    int argc;
+    struct t_relay_weechat_msg *msg;
+    struct t_hashtable *hashtable;
+    char *totp_secret, string[64];
 
-    *algorithm = NULL;
-    *salt = NULL;
-    *salt_size = 0;
-    *iterations = 0;
-    *hash_pbkdf2 = NULL;
+    totp_secret = weechat_string_eval_expression (
+        weechat_config_string (relay_config_network_totp_secret),
+        NULL, NULL, NULL);
 
-    if (!parameters)
-        return;
-
-    argv = weechat_string_split (parameters, ":", NULL, 0, 0, &argc);
-
-    if (!argv || (argc < 4))
+    hashtable = weechat_hashtable_new (32,
+                                       WEECHAT_HASHTABLE_STRING,
+                                       WEECHAT_HASHTABLE_STRING,
+                                       NULL, NULL);
+    if (hashtable)
     {
-        /* not enough parameters */
-        if (argv)
-            weechat_string_free_split (argv);
-        return;
+        weechat_hashtable_set (
+            hashtable,
+            "password_hash_algo",
+            (client->password_hash_algo >= 0) ?
+            relay_auth_password_hash_algo_name[client->password_hash_algo] : "");
+        snprintf (string, sizeof (string), "%d", client->password_hash_iterations);
+        weechat_hashtable_set (
+            hashtable,
+            "password_hash_iterations",
+            string);
+        weechat_hashtable_set (
+            hashtable,
+            "nonce",
+            client->nonce);
+        weechat_hashtable_set (
+            hashtable,
+            "totp",
+            (totp_secret && totp_secret[0]) ? "on" : "off");
+        weechat_hashtable_set (
+            hashtable,
+            "compression",
+            relay_weechat_compression_string[RELAY_WEECHAT_DATA(client, compression)]);
+
+        msg = relay_weechat_msg_new (id);
+        if (msg)
+        {
+            relay_weechat_msg_add_type (msg, RELAY_WEECHAT_MSG_OBJ_HASHTABLE);
+            relay_weechat_msg_add_hashtable (msg, hashtable);
+
+            /* send message */
+            relay_weechat_msg_send (client, msg);
+            relay_weechat_msg_free (msg);
+        }
+
+        weechat_hashtable_free (hashtable);
     }
 
-    /* parameter 1: algorithm */
-    if ((strcmp (argv[0], "sha256") == 0)
-        || (strcmp (argv[0], "sha512") == 0))
-    {
-        *algorithm = strdup (argv[0]);
-    }
-
-    /* parameter 2: salt */
-    *salt = malloc (strlen (argv[1]) + 1);
-    if (*salt)
-        *salt_size = weechat_string_base_decode (16, argv[1], *salt);
-
-    /* parameter 3: iterations */
-    *iterations = (int)strtol (argv[2], &error, 10);
-    if (!error || error[0])
-        *iterations = 0;
-
-    /* parameter 4: the PBKDF2 hash */
-    *hash_pbkdf2 = strdup (argv[3]);
-
-    weechat_string_free_split (argv);
+    if (totp_secret)
+        free (totp_secret);
 }
 
+
 /*
- * Checks if hashed password received is valid.
- *
- * Format of hash_password is: algorithm:hash
- *
- * Returns 1 if the hashed password is valid, otherwise 0.
+ * Callback for command "handshake" (from client).
  */
 
-int
-relay_weechat_protocol_check_hash (const char *hashed_password,
-                                   const char *password)
+RELAY_WEECHAT_PROTOCOL_CALLBACK(handshake)
 {
-    const char *pos_hash;
-    char *hash_algo, hash[512 / 8], hash_hexa[((512 / 8) * 2) + 1];
-    char *hash_pbkdf2_algo, *salt, *hash_pbkdf2;
-    int rc, hash_size, salt_size, iterations;
+    char **options, **auths, *pos;
+    int i, j, index_hash_algo, hash_algo_found, auth_allowed, compression;
+    int password_received, plain_text_password;
 
-    rc = 0;
+    RELAY_WEECHAT_PROTOCOL_MIN_ARGS(0);
 
-    if (!hashed_password || !password)
-        goto end;
+    if (client->status != RELAY_STATUS_WAITING_AUTH)
+        return WEECHAT_RC_OK;
 
-    pos_hash = strchr (hashed_password, ':');
-    if (!pos_hash)
-        goto end;
-
-    hash_algo = weechat_strndup (hashed_password, pos_hash - hashed_password);
-    if (!hash_algo)
-        goto end;
-
-    pos_hash++;
-
-    if ((strcmp (hash_algo, "sha256") == 0)
-        || (strcmp (hash_algo, "sha512") == 0))
+    /* only one handshake is allowed */
+    if (RELAY_WEECHAT_DATA(client, handshake_done))
     {
-        if (weechat_crypto_hash (password, strlen (password), hash_algo,
-                                 hash, &hash_size))
-        {
-            weechat_string_base_encode (16, hash, hash_size, hash_hexa);
-            if (weechat_strcasecmp (hash_hexa, pos_hash) == 0)
-                rc = 1;
-        }
+        relay_client_set_status (client, RELAY_STATUS_AUTH_FAILED);
+        return WEECHAT_RC_OK;
     }
-    else if (strcmp (hash_algo, "pbkdf2") == 0)
+
+    hash_algo_found = -1;
+    password_received = 0;
+
+    options = (argc > 0) ?
+        weechat_string_split_command (argv_eol[0], ',') : NULL;
+    if (options)
     {
-        relay_weechat_protocol_parse_pbkdf2 (pos_hash,
-                                             &hash_pbkdf2_algo,
-                                             &salt,
-                                             &salt_size,
-                                             &iterations,
-                                             &hash_pbkdf2);
-        if (hash_pbkdf2_algo && salt && (salt_size > 0) && (iterations > 0)
-            && hash_pbkdf2)
+        for (i = 0; options[i]; i++)
         {
-            if (weechat_crypto_hash_pbkdf2 (password, strlen (password),
-                                            hash_pbkdf2_algo,
-                                            salt, salt_size,
-                                            iterations,
-                                            hash, &hash_size))
+            pos = strchr (options[i], '=');
+            if (pos)
             {
-                weechat_string_base_encode (16, hash, hash_size, hash_hexa);
-                if (weechat_strcasecmp (hash_hexa, hash_pbkdf2) == 0)
-                    rc = 1;
+                pos[0] = '\0';
+                pos++;
+                if (strcmp (options[i], "password_hash_algo") == 0)
+                {
+                    password_received = 1;
+                    auths = weechat_string_split (
+                        pos,
+                        ":",
+                        NULL,
+                        WEECHAT_STRING_SPLIT_STRIP_LEFT
+                        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                        0,
+                        NULL);
+                    if (auths)
+                    {
+                        for (j = 0; auths[j]; j++)
+                        {
+                            index_hash_algo = relay_auth_password_hash_algo_search (
+                                auths[j]);
+                            if ((index_hash_algo >= 0) && (index_hash_algo > hash_algo_found))
+                            {
+                                auth_allowed = weechat_string_match_list (
+                                    relay_auth_password_hash_algo_name[index_hash_algo],
+                                    (const char **)relay_config_network_password_hash_algo_list,
+                                    1);
+                                if (auth_allowed)
+                                    hash_algo_found = index_hash_algo;
+                            }
+                        }
+                        weechat_string_free_split (auths);
+                    }
+                }
+                else if (strcmp (options[i], "compression") == 0)
+                {
+                    compression = relay_weechat_compression_search (pos);
+                    if (compression >= 0)
+                        RELAY_WEECHAT_DATA(client, compression) = compression;
+                }
             }
         }
-        if (hash_pbkdf2_algo)
-            free (hash_pbkdf2_algo);
-        if (salt)
-            free (salt);
-        if (hash_pbkdf2)
-            free (hash_pbkdf2);
+        weechat_string_free_split_command (options);
     }
 
-    free (hash_algo);
+    if (!password_received)
+    {
+        plain_text_password = weechat_string_match_list (
+            relay_auth_password_hash_algo_name[0],
+            (const char **)relay_config_network_password_hash_algo_list,
+            1);
+        if (plain_text_password)
+            hash_algo_found = 0;
+    }
 
-end:
-    return rc;
+    client->password_hash_algo = hash_algo_found;
+
+    relay_weechat_protocol_handshake_reply (client, id);
+
+    RELAY_WEECHAT_DATA(client, handshake_done) = 1;
+
+    /* if no algo was found, we close the connection immediately */
+    if (client->password_hash_algo < 0)
+        relay_client_set_status (client, RELAY_STATUS_AUTH_FAILED);
+
+    return WEECHAT_RC_OK;
 }
 
 /*
@@ -328,12 +349,12 @@ end:
 
 RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
 {
-    char **options, *pos, *password, *totp_secret, *info_totp_args, *info_totp;
+    char **options, *pos, *relay_password, *totp_secret, *info_totp_args, *info_totp;
     int i, compression, length, password_received, totp_received;
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(0);
 
-    password = weechat_string_eval_expression (
+    relay_password = weechat_string_eval_expression (
         weechat_config_string (relay_config_network_password),
         NULL, NULL, NULL);
     totp_secret = weechat_string_eval_expression (
@@ -357,17 +378,14 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
                 if (strcmp (options[i], "password") == 0)
                 {
                     password_received = 1;
-                    if (password && (strcmp (password, pos) == 0))
+                    if (relay_auth_password (client, pos, relay_password))
                         RELAY_WEECHAT_DATA(client, password_ok) = 1;
                 }
                 else if (strcmp (options[i], "password_hash") == 0)
                 {
                     password_received = 1;
-                    if (password
-                        && relay_weechat_protocol_check_hash (pos, password))
-                    {
+                    if (relay_auth_password_hash (client, pos, relay_password))
                         RELAY_WEECHAT_DATA(client, password_ok) = 1;
-                    }
                 }
                 else if (strcmp (options[i], "totp") == 0)
                 {
@@ -405,27 +423,27 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
     }
 
     /* if no password received and password is empty, it's OK */
-    if (!password_received && (!password || !password[0]))
+    if (!password_received && (!relay_password || !relay_password[0]))
         RELAY_WEECHAT_DATA(client, password_ok) = 1;
 
     /* if no TOTP received and totp_secret is empty, it's OK */
     if (!totp_received && (!totp_secret || !totp_secret[0]))
         RELAY_WEECHAT_DATA(client, totp_ok) = 1;
 
-    if (RELAY_WEECHAT_DATA(client, password_ok)
-        && RELAY_WEECHAT_DATA(client, totp_ok))
+    if (RELAY_WEECHAT_AUTH_OK(client))
     {
         weechat_hook_signal_send ("relay_client_auth_ok",
                                   WEECHAT_HOOK_SIGNAL_POINTER,
                                   client);
+        relay_client_set_status (client, RELAY_STATUS_CONNECTED);
     }
     else
     {
         relay_client_set_status (client, RELAY_STATUS_AUTH_FAILED);
     }
 
-    if (password)
-        free (password);
+    if (relay_password)
+        free (relay_password);
     if (totp_secret)
         free (totp_secret);
 
@@ -557,8 +575,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(nicklist)
             if (weechat_relay_plugin->debug >= 1)
             {
                 weechat_printf (NULL,
-                                _("%s: invalid buffer pointer in message: "
-                                  "\"%s %s\""),
+                                _("%s: invalid buffer in message: \"%s %s\""),
                                 RELAY_PLUGIN_NAME,
                                 command,
                                 argv_eol[0]);
@@ -602,8 +619,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(input)
         if (weechat_relay_plugin->debug >= 1)
         {
             weechat_printf (NULL,
-                            _("%s: invalid buffer pointer in message: "
-                              "\"%s %s\""),
+                            _("%s: invalid buffer in message: \"%s %s\""),
                             RELAY_PLUGIN_NAME,
                             command,
                             argv[0]);
@@ -652,6 +668,178 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(input)
     return WEECHAT_RC_OK;
 }
 
+/*
+ * Callback for command "completion" (from client).
+ *
+ * Message looks like:
+ *   completion core.weechat -1 /help fi
+ *   input irc.freenode.#weechat 5 /quernick
+ *   input 0x12345678 -1 nick
+ */
+
+RELAY_WEECHAT_PROTOCOL_CALLBACK(completion)
+{
+    struct t_gui_buffer *ptr_buffer;
+    struct t_gui_completion *completion;
+    struct t_gui_completion_word *word;
+    struct t_hdata *ptr_hdata_completion, *ptr_hdata_completion_word;
+    struct t_arraylist *ptr_list;
+    struct t_relay_weechat_msg *msg;
+    char *error, *pos_data;
+    int i, position, length_data, context, pos_start, size;
+
+    RELAY_WEECHAT_PROTOCOL_MIN_ARGS(0);
+
+    completion = NULL;
+
+    /* return an empty hdata as error if there are not enough arguments */
+    if (argc < 2)
+        goto error;
+
+    ptr_buffer = relay_weechat_protocol_get_buffer (argv[0]);
+    if (!ptr_buffer)
+    {
+        if (weechat_relay_plugin->debug >= 1)
+        {
+            weechat_printf (NULL,
+                            _("%s: invalid buffer in message: \"%s %s\""),
+                            RELAY_PLUGIN_NAME,
+                            command,
+                            argv[0]);
+        }
+        goto error;
+    }
+
+    error = NULL;
+    position = (int)strtol (argv[1], &error, 10);
+    if (!error || error[0])
+        goto error;
+
+    pos_data = strchr (argv_eol[1], ' ');
+    if (pos_data)
+        pos_data++;
+
+    length_data = strlen ((pos_data) ? pos_data : "");
+    if ((position < 0) || (position > length_data))
+        position = length_data;
+
+    completion = weechat_completion_new (ptr_buffer);
+    if (!completion)
+        goto error;
+
+    if (!weechat_completion_search (completion,
+                                    (pos_data) ? pos_data : "",
+                                    position,
+                                    1))
+    {
+        goto error;
+    }
+
+    ptr_hdata_completion = weechat_hdata_get ("completion");
+    if (!ptr_hdata_completion)
+        goto error;
+
+    ptr_hdata_completion_word = weechat_hdata_get ("completion_word");
+    if (!ptr_hdata_completion_word)
+        goto error;
+
+    ptr_list = weechat_hdata_pointer (ptr_hdata_completion, completion, "list");
+    if (!ptr_list)
+        goto error;
+
+    msg = relay_weechat_msg_new (id);
+    if (msg)
+    {
+        relay_weechat_msg_add_type (msg, RELAY_WEECHAT_MSG_OBJ_HDATA);
+        relay_weechat_msg_add_string (msg, "completion");
+        relay_weechat_msg_add_string (msg,
+                                      "context:str,"
+                                      "base_word:str,"
+                                      "pos_start:int,"
+                                      "pos_end:int,"
+                                      "add_space:int,"
+                                      "list:arr");
+        relay_weechat_msg_add_int (msg, 1); /* count */
+        relay_weechat_msg_add_pointer (msg, completion);
+        /* context */
+        context = weechat_hdata_integer (ptr_hdata_completion, completion,
+                                         "context");
+        switch (context)
+        {
+            case 0:
+                relay_weechat_msg_add_string (msg, "null");
+                break;
+            case 1:
+                relay_weechat_msg_add_string (msg, "command");
+                break;
+            case 2:
+                relay_weechat_msg_add_string (msg, "command_arg");
+                break;
+            default:
+                relay_weechat_msg_add_string (msg, "auto");
+                break;
+        }
+        /* base_word */
+        relay_weechat_msg_add_string (
+            msg,
+            weechat_hdata_string (ptr_hdata_completion,
+                                  completion, "base_word"));
+        /* pos_start */
+        pos_start = weechat_hdata_integer (ptr_hdata_completion,
+                                           completion, "position_replace");
+        relay_weechat_msg_add_int (msg, pos_start);
+
+        /* pos_end */
+        relay_weechat_msg_add_int (
+            msg,
+            (position > pos_start) ? position - 1 : position);
+        /* add_space */
+        relay_weechat_msg_add_int (
+            msg,
+            weechat_hdata_integer (ptr_hdata_completion,
+                                   completion, "add_space"));
+        /* list */
+        relay_weechat_msg_add_type (msg, RELAY_WEECHAT_MSG_OBJ_STRING);
+        size = weechat_arraylist_size (ptr_list);
+        relay_weechat_msg_add_int (msg, size);
+        for (i = 0; i < size; i++)
+        {
+            word = (struct t_gui_completion_word *)weechat_arraylist_get (
+                ptr_list, i);
+            relay_weechat_msg_add_string (
+                msg,
+                weechat_hdata_string (ptr_hdata_completion_word, word, "word"));
+        }
+
+        /* send message */
+        relay_weechat_msg_send (client, msg);
+        relay_weechat_msg_free (msg);
+    }
+
+    weechat_completion_free (completion);
+
+    return WEECHAT_RC_OK;
+
+error:
+    if (completion)
+        weechat_completion_free (completion);
+
+    msg = relay_weechat_msg_new (id);
+    if (msg)
+    {
+        relay_weechat_msg_add_type (msg, RELAY_WEECHAT_MSG_OBJ_HDATA);
+        relay_weechat_msg_add_string (msg, "completion");
+        relay_weechat_msg_add_string (msg, NULL);  /* keys */
+        relay_weechat_msg_add_int (msg, 0);  /* count */
+
+        /* send message */
+        relay_weechat_msg_send (client, msg);
+        relay_weechat_msg_free (msg);
+    }
+
+    return WEECHAT_RC_OK;
+}
+
 /*
  * Callback for signals "buffer_*".
  */
@@ -952,8 +1140,9 @@ relay_weechat_protocol_signal_buffer_cb (const void *pointer, void *data,
                           (unsigned long)ptr_line_data);
                 relay_weechat_msg_add_hdata (msg, cmd_hdata,
                                              "buffer,date,date_printed,"
-                                             "displayed,highlight,tags_array,"
-                                             "prefix,message");
+                                             "displayed,notify_level,"
+                                             "highlight,tags_array,prefix,"
+                                             "message");
                 relay_weechat_msg_send (ptr_client, msg);
                 relay_weechat_msg_free (msg);
             }
@@ -1546,12 +1735,14 @@ relay_weechat_protocol_recv (struct t_relay_client *client, const char *data)
     char *pos, *id, *command, **argv, **argv_eol;
     int i, argc, return_code;
     struct t_relay_weechat_protocol_cb protocol_cb[] =
-        { { "init", &relay_weechat_protocol_cb_init },
+        { { "handshake", &relay_weechat_protocol_cb_handshake },
+          { "init", &relay_weechat_protocol_cb_init },
           { "hdata", &relay_weechat_protocol_cb_hdata },
           { "info", &relay_weechat_protocol_cb_info },
           { "infolist", &relay_weechat_protocol_cb_infolist },
           { "nicklist", &relay_weechat_protocol_cb_nicklist },
           { "input", &relay_weechat_protocol_cb_input },
+          { "completion", &relay_weechat_protocol_cb_completion },
           { "sync", &relay_weechat_protocol_cb_sync },
           { "desync", &relay_weechat_protocol_cb_desync },
           { "test", &relay_weechat_protocol_cb_test },
@@ -1630,13 +1821,13 @@ relay_weechat_protocol_recv (struct t_relay_client *client, const char *data)
     {
         if (strcmp (protocol_cb[i].name, command) == 0)
         {
-            if ((strcmp (protocol_cb[i].name, "init") != 0)
-                && (!RELAY_WEECHAT_DATA(client, password_ok)
-                    || !RELAY_WEECHAT_DATA(client, totp_ok)))
+            if ((strcmp (protocol_cb[i].name, "handshake") != 0)
+                && (strcmp (protocol_cb[i].name, "init") != 0)
+                && !RELAY_WEECHAT_AUTH_OK(client))
             {
                 /*
-                 * command is not "init" and password or totp are not set?
-                 * then close connection!
+                 * command is not handshake/init and password or totp are not
+                 * set? then close connection!
                  */
                 relay_client_set_status (client,
                                          RELAY_STATUS_AUTH_FAILED);
