@@ -40,7 +40,7 @@
 #include "../relay-raw.h"
 
 
-char *relay_weechat_compression_string[] = /* strings for compressions      */
+char *relay_weechat_compression_string[] = /* strings for compression       */
 { "off", "zlib" };
 
 
@@ -170,6 +170,7 @@ relay_weechat_alloc (struct t_relay_client *client)
     if (!client->protocol_data)
         return;
 
+    RELAY_WEECHAT_DATA(client, handshake_done) = 0;
     RELAY_WEECHAT_DATA(client, password_ok) = 0;
     RELAY_WEECHAT_DATA(client, totp_ok) = 0;
     RELAY_WEECHAT_DATA(client, compression) = RELAY_WEECHAT_COMPRESSION_ZLIB;
@@ -212,6 +213,11 @@ relay_weechat_alloc_with_infolist (struct t_relay_client *client,
     if (client->protocol_data)
     {
         /* general stuff */
+        /* "handshake_done" is new in WeeChat 2.9 */
+        if (weechat_infolist_search_var (infolist, "handshake_done"))
+            RELAY_WEECHAT_DATA(client, handshake_done) = weechat_infolist_integer (infolist, "handshake_done");
+        else
+            RELAY_WEECHAT_DATA(client, handshake_done) = 0;
         RELAY_WEECHAT_DATA(client, password_ok) = weechat_infolist_integer (
             infolist, "password_ok");
         /* "totp_ok" is new in WeeChat 2.4 */
@@ -266,6 +272,21 @@ relay_weechat_alloc_with_infolist (struct t_relay_client *client,
     }
 }
 
+/*
+ * Returns the client initial status: it is always  "waiting_auth" for weechat
+ * protocol because we always expect the "init" command, even without any
+ * password.
+ */
+
+enum t_relay_status
+relay_weechat_get_initial_status (struct t_relay_client *client)
+{
+    /* make C compiler happy */
+    (void) client;
+
+    return RELAY_STATUS_WAITING_AUTH;
+}
+
 /*
  * Frees relay data specific to WeeChat protocol.
  */
@@ -310,6 +331,8 @@ relay_weechat_add_to_infolist (struct t_infolist_item *item,
     if (!item || !client)
         return 0;
 
+    if (!weechat_infolist_new_var_integer (item, "handshake_done", RELAY_WEECHAT_DATA(client, handshake_done)))
+        return 0;
     if (!weechat_infolist_new_var_integer (item, "password_ok", RELAY_WEECHAT_DATA(client, password_ok)))
         return 0;
     if (!weechat_infolist_new_var_integer (item, "totp_ok", RELAY_WEECHAT_DATA(client, totp_ok)))
@@ -331,20 +354,21 @@ relay_weechat_print_log (struct t_relay_client *client)
 {
     if (client->protocol_data)
     {
-        weechat_log_printf ("    password_ok. . . . . . : %d",   RELAY_WEECHAT_DATA(client, password_ok));
-        weechat_log_printf ("    totp_ok. . . . . . . . : %d",   RELAY_WEECHAT_DATA(client, totp_ok));
-        weechat_log_printf ("    compression. . . . . . : %d",   RELAY_WEECHAT_DATA(client, compression));
-        weechat_log_printf ("    buffers_sync . . . . . : 0x%lx (hashtable: '%s')",
+        weechat_log_printf ("    handshake_done. . . . . : %d",   RELAY_WEECHAT_DATA(client, handshake_done));
+        weechat_log_printf ("    password_ok . . . . . . : %d",   RELAY_WEECHAT_DATA(client, password_ok));
+        weechat_log_printf ("    totp_ok . . . . . . . . : %d",   RELAY_WEECHAT_DATA(client, totp_ok));
+        weechat_log_printf ("    compression . . . . . . : %d",   RELAY_WEECHAT_DATA(client, compression));
+        weechat_log_printf ("    buffers_sync. . . . . . : 0x%lx (hashtable: '%s')",
                             RELAY_WEECHAT_DATA(client, buffers_sync),
                             weechat_hashtable_get_string (RELAY_WEECHAT_DATA(client, buffers_sync),
                                                           "keys_values"));
-        weechat_log_printf ("    hook_signal_buffer . . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_signal_buffer));
-        weechat_log_printf ("    hook_hsignal_nicklist. : 0x%lx", RELAY_WEECHAT_DATA(client, hook_hsignal_nicklist));
-        weechat_log_printf ("    hook_signal_upgrade. . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_signal_upgrade));
-        weechat_log_printf ("    buffers_nicklist . . . : 0x%lx (hashtable: '%s')",
+        weechat_log_printf ("    hook_signal_buffer. . . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_signal_buffer));
+        weechat_log_printf ("    hook_hsignal_nicklist . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_hsignal_nicklist));
+        weechat_log_printf ("    hook_signal_upgrade . . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_signal_upgrade));
+        weechat_log_printf ("    buffers_nicklist. . . . : 0x%lx (hashtable: '%s')",
                             RELAY_WEECHAT_DATA(client, buffers_nicklist),
                             weechat_hashtable_get_string (RELAY_WEECHAT_DATA(client, buffers_nicklist),
                                                           "keys_values"));
-        weechat_log_printf ("    hook_timer_nicklist. . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_timer_nicklist));
+        weechat_log_printf ("    hook_timer_nicklist . . : 0x%lx", RELAY_WEECHAT_DATA(client, hook_timer_nicklist));
     }
 }
