@@ -33,9 +33,6 @@
 /* hashtable used to evaluate "conditions" */
 struct t_hashtable *trigger_callback_hashtable_options_conditions = NULL;
 
-/* hashtable used to replace with regex */
-struct t_hashtable *trigger_callback_hashtable_options_regex = NULL;
-
 
 /*
  * Parses an IRC message.
@@ -125,6 +122,21 @@ trigger_callback_get_irc_server_channel (const char *irc_server_name,
     }
 }
 
+/*
+ * Sets variables common to all triggers in a hashtable:
+ * - tg_trigger_name
+ */
+
+void
+trigger_callback_set_common_vars (struct t_trigger *trigger,
+                                  struct t_hashtable *hashtable)
+{
+    if (!trigger || !hashtable)
+        return;
+
+    weechat_hashtable_set (hashtable, "tg_trigger_name", trigger->name);
+}
+
 /*
  * Sets variables in "extra_vars" hashtable using tags from message.
  *
@@ -233,6 +245,7 @@ trigger_callback_replace_regex (struct t_trigger *trigger,
     char *value;
     const char *ptr_key, *ptr_value;
     int i, pointers_allocated;
+    struct t_hashtable *hashtable_options_regex;
 
     pointers_allocated = 0;
 
@@ -283,8 +296,14 @@ trigger_callback_replace_regex (struct t_trigger *trigger,
             ptr_value = weechat_hashtable_get (extra_vars, ptr_key);
         }
 
+        hashtable_options_regex = weechat_hashtable_new (
+            32,
+            WEECHAT_HASHTABLE_STRING,
+            WEECHAT_HASHTABLE_STRING,
+            NULL, NULL);
+
         weechat_hashtable_set (pointers, "regex", trigger->regex[i].regex);
-        weechat_hashtable_set (trigger_callback_hashtable_options_regex,
+        weechat_hashtable_set (hashtable_options_regex,
                                "regex_replace",
                                trigger->regex[i].replace_escaped);
 
@@ -292,7 +311,9 @@ trigger_callback_replace_regex (struct t_trigger *trigger,
             ptr_value,
             pointers,
             extra_vars,
-            trigger_callback_hashtable_options_regex);
+            hashtable_options_regex);
+
+        weechat_hashtable_free (hashtable_options_regex);
 
         if (value)
         {
@@ -393,9 +414,13 @@ trigger_callback_run_command (struct t_trigger *trigger,
  *   2. check conditions (if false, exit)
  *   3. replace text with regex
  *   4. execute command(s)
+ *
+ * Returns:
+ *   1: conditions were true (or no condition set in trigger)
+ *   0: conditions were false
  */
 
-void
+int
 trigger_callback_execute (struct t_trigger *trigger,
                           struct t_gui_buffer *buffer,
                           struct t_hashtable *pointers,
@@ -422,7 +447,11 @@ trigger_callback_execute (struct t_trigger *trigger,
         /* execute command(s) */
         trigger_callback_run_command (trigger, buffer, pointers, extra_vars,
                                       display_monitor);
+
+        return 1;
     }
+
+    return 0;
 }
 
 /*
@@ -500,8 +529,9 @@ trigger_callback_signal_cb (const void *pointer, void *data,
     }
 
     /* add data in hashtable used for conditions/replace/command */
-    ptr_signal_data = NULL;
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (extra_vars, "tg_signal", signal);
+    ptr_signal_data = NULL;
     if (strcmp (type_data, WEECHAT_HOOK_SIGNAL_STRING) == 0)
     {
         ptr_signal_data = (const char *)signal_data;
@@ -529,7 +559,8 @@ trigger_callback_signal_cb (const void *pointer, void *data,
     weechat_hashtable_set (extra_vars, "tg_signal_data", ptr_signal_data);
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -574,10 +605,12 @@ trigger_callback_hsignal_cb (const void *pointer, void *data,
     }
 
     /* add data in hashtable used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (extra_vars, "tg_signal", signal);
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -594,10 +627,11 @@ trigger_callback_modifier_cb (const void *pointer, void *data,
 {
     struct t_gui_buffer *buffer;
     const char *ptr_string;
-    char *string_modified, *pos, *pos2, *plugin_name, *buffer_name;
-    char *buffer_full_name, *str_tags, **tags, *prefix, *string_no_color;
-    int length, num_tags;
+    char *string_modified, *pos, *buffer_pointer;
+    char *str_tags, **tags, *prefix, *string_no_color;
+    int length, num_tags, rc;
     void *ptr_irc_server, *ptr_irc_channel;
+    unsigned long value;
 
     TRIGGER_CALLBACK_CB_INIT(NULL);
 
@@ -635,6 +669,7 @@ trigger_callback_modifier_cb (const void *pointer, void *data,
     }
 
     /* add data in hashtable used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (extra_vars, "tg_modifier", modifier);
     weechat_hashtable_set (extra_vars, "tg_modifier_data", modifier_data);
     weechat_hashtable_set (extra_vars, "tg_string", string);
@@ -700,41 +735,32 @@ trigger_callback_modifier_cb (const void *pointer, void *data,
 
         /*
          * extract buffer/tags from modifier data
-         * (format: "plugin;buffer_name;tags")
+         * (format: "buffer_pointer;tags")
          */
         pos = strchr (modifier_data, ';');
         if (pos)
         {
-            plugin_name = weechat_strndup (modifier_data, pos - modifier_data);
-            if (plugin_name)
+            buffer_pointer = weechat_strndup (modifier_data,
+                                              pos - modifier_data);
+            if (buffer_pointer)
             {
-                weechat_hashtable_set (extra_vars, "tg_plugin", plugin_name);
-                pos++;
-                pos2 = strchr (pos, ';');
-                if (pos2)
+                rc = sscanf (buffer_pointer, "0x%lx", &value);
+                if ((rc != EOF) && (rc != 0))
                 {
-                    buffer_name = weechat_strndup (pos, pos2 - pos);
-                    if (buffer_name)
-                    {
-                        buffer = weechat_buffer_search (plugin_name,
-                                                        buffer_name);
-                        length = strlen (plugin_name) + 1 + strlen (buffer_name) + 1;
-                        buffer_full_name = malloc (length);
-                        if (buffer_full_name)
-                        {
-                            snprintf (buffer_full_name, length,
-                                      "%s.%s", plugin_name, buffer_name);
-                            weechat_hashtable_set (extra_vars, "tg_buffer",
-                                                   buffer_full_name);
-                            free (buffer_full_name);
-                        }
-                        free (buffer_name);
-                    }
-                    pos2++;
-                    if (pos2[0])
+                    buffer = (struct t_gui_buffer *)value;
+                    weechat_hashtable_set (
+                        extra_vars,
+                        "tg_plugin",
+                        weechat_buffer_get_string (buffer, "plugin"));
+                    weechat_hashtable_set (
+                        extra_vars,
+                        "tg_buffer",
+                        weechat_buffer_get_string (buffer, "full_name"));
+                    pos++;
+                    if (pos[0])
                     {
                         tags = weechat_string_split (
-                            pos2,
+                            pos,
                             ",",
                             NULL,
                             WEECHAT_STRING_SPLIT_STRIP_LEFT
@@ -742,18 +768,18 @@ trigger_callback_modifier_cb (const void *pointer, void *data,
                             | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
                             0,
                             &num_tags);
-                        length = 1 + strlen (pos2) + 1 + 1;
+                        length = 1 + strlen (pos) + 1 + 1;
                         str_tags = malloc (length);
                         if (str_tags)
                         {
-                            snprintf (str_tags, length, ",%s,", pos2);
+                            snprintf (str_tags, length, ",%s,", pos);
                             weechat_hashtable_set (extra_vars, "tg_tags",
                                                    str_tags);
                             free (str_tags);
                         }
                     }
                 }
-                free (plugin_name);
+                free (buffer_pointer);
             }
         }
         weechat_hashtable_set (pointers, "buffer", buffer);
@@ -769,7 +795,8 @@ trigger_callback_modifier_cb (const void *pointer, void *data,
     }
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL);
+    (void) trigger_callback_execute (trigger, buffer, pointers, extra_vars,
+                                     NULL);
 
 end:
     ptr_string = weechat_hashtable_get (extra_vars, "tg_string");
@@ -815,6 +842,7 @@ trigger_callback_line_cb (const void *pointer, void *data,
     weechat_hashtable_remove (extra_vars, "tags");
 
     /* add data in hashtables used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     ptr_value = weechat_hashtable_get (line, "buffer");
     if (!ptr_value || (ptr_value[0] != '0') || (ptr_value[1] != 'x'))
         goto end;
@@ -866,8 +894,8 @@ trigger_callback_line_cb (const void *pointer, void *data,
     }
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, buffer, pointers, extra_vars,
-                              vars_updated);
+    (void) trigger_callback_execute (trigger, buffer, pointers, extra_vars,
+                                     vars_updated);
 
     hashtable = weechat_hashtable_new (32,
                                        WEECHAT_HASHTABLE_STRING,
@@ -951,6 +979,7 @@ trigger_callback_print_cb  (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
 
     /* add data in hashtables used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (pointers, "buffer", buffer);
     date_tmp = localtime (&date);
     if (date_tmp)
@@ -997,7 +1026,8 @@ trigger_callback_print_cb  (const void *pointer, void *data,
         goto end;
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -1012,7 +1042,7 @@ trigger_callback_command_cb  (const void *pointer, void *data,
                               struct t_gui_buffer *buffer,
                               int argc, char **argv, char **argv_eol)
 {
-    char str_name[32];
+    char str_name[32], str_temp[128];
     int i;
 
     TRIGGER_CALLBACK_CB_INIT(WEECHAT_RC_OK);
@@ -1021,7 +1051,10 @@ trigger_callback_command_cb  (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
 
     /* add data in hashtables used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (pointers, "buffer", buffer);
+    snprintf (str_temp, sizeof (str_temp), "%d", argc);
+    weechat_hashtable_set (extra_vars, "tg_argc", str_temp);
     for (i = 0; i < argc; i++)
     {
         snprintf (str_name, sizeof (str_name), "tg_argv%d", i);
@@ -1031,7 +1064,8 @@ trigger_callback_command_cb  (const void *pointer, void *data,
     }
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -1052,11 +1086,13 @@ trigger_callback_command_run_cb  (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
 
     /* add data in hashtables used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (pointers, "buffer", buffer);
     weechat_hashtable_set (extra_vars, "tg_command", command);
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, buffer, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -1093,6 +1129,7 @@ trigger_callback_timer_cb  (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
 
     /* add data in hashtable used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     snprintf (str_temp, sizeof (str_temp), "%d", remaining_calls);
     weechat_hashtable_set (extra_vars, "tg_remaining_calls", str_temp);
     date = time (NULL);
@@ -1106,7 +1143,8 @@ trigger_callback_timer_cb  (const void *pointer, void *data,
     }
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -1125,11 +1163,13 @@ trigger_callback_config_cb  (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
 
     /* add data in hashtable used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (extra_vars, "tg_option", option);
     weechat_hashtable_set (extra_vars, "tg_value", value);
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL);
+    if (!trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL))
+        trigger_rc = WEECHAT_RC_OK;
 
 end:
     TRIGGER_CALLBACK_CB_END(trigger_rc);
@@ -1152,6 +1192,7 @@ trigger_callback_focus_cb (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_POINTERS;
 
     /* add data in hashtables used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, info);
     ptr_value = weechat_hashtable_get (info, "_window");
     if (ptr_value && ptr_value[0] && (strncmp (ptr_value, "0x", 2) == 0))
     {
@@ -1168,7 +1209,7 @@ trigger_callback_focus_cb (const void *pointer, void *data,
     }
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, info, NULL);
+    (void) trigger_callback_execute (trigger, NULL, pointers, info, NULL);
 
 end:
     TRIGGER_CALLBACK_CB_END(info);
@@ -1190,12 +1231,14 @@ trigger_callback_info_cb (const void *pointer, void *data,
     TRIGGER_CALLBACK_CB_NEW_EXTRA_VARS;
 
     /* add data in hashtable used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (extra_vars, "tg_info_name", info_name);
     weechat_hashtable_set (extra_vars, "tg_arguments", arguments);
     weechat_hashtable_set (extra_vars, "tg_info", "");
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, extra_vars, NULL);
+    (void) trigger_callback_execute (trigger, NULL, pointers, extra_vars,
+                                     NULL);
 
 end:
     ptr_info = weechat_hashtable_get (extra_vars, "tg_info");
@@ -1227,11 +1270,12 @@ trigger_callback_info_hashtable_cb (const void *pointer, void *data,
     extra_vars = weechat_hashtable_dup (hashtable);
 
     /* add data in hashtable used for conditions/replace/command */
+    trigger_callback_set_common_vars (trigger, extra_vars);
     weechat_hashtable_set (extra_vars, "tg_info_name", info_name);
 
     /* execute the trigger (conditions, regex, command) */
-    trigger_callback_execute (trigger, NULL, pointers, extra_vars,
-                              vars_updated);
+    (void) trigger_callback_execute (trigger, NULL, pointers, extra_vars,
+                                     vars_updated);
 
     ret_hashtable = weechat_hashtable_new (32,
                                            WEECHAT_HASHTABLE_STRING,
@@ -1275,12 +1319,6 @@ trigger_callback_init ()
         weechat_hashtable_set (trigger_callback_hashtable_options_conditions,
                                "type", "condition");
     }
-
-    trigger_callback_hashtable_options_regex = weechat_hashtable_new (
-        32,
-        WEECHAT_HASHTABLE_STRING,
-        WEECHAT_HASHTABLE_STRING,
-        NULL, NULL);
 }
 
 /*
@@ -1292,6 +1330,4 @@ trigger_callback_end ()
 {
     if (trigger_callback_hashtable_options_conditions)
         weechat_hashtable_free (trigger_callback_hashtable_options_conditions);
-    if (trigger_callback_hashtable_options_regex)
-        weechat_hashtable_free (trigger_callback_hashtable_options_regex);
 }
