@@ -71,6 +71,10 @@ def test_strings():
     check(weechat.string_format_size(1) == '1 byte')
     check(weechat.string_format_size(2097152) == '2.10 MB')
     check(weechat.string_format_size(420000000) == '420.00 MB')
+    check(weechat.string_color_code_size('') == 0)
+    check(weechat.string_color_code_size('test') == 0)
+    str_color = weechat.color('yellow,red')
+    check(weechat.string_color_code_size(str_color) == 7)
     check(weechat.string_remove_color('test', '?') == 'test')
     check(weechat.string_is_command_char('/test') == 1)
     check(weechat.string_is_command_char('test') == 0)
@@ -160,9 +164,9 @@ def completion_cb(data, completion_item, buf, completion):
     """Completion callback."""
     check(data == 'completion_data')
     check(completion_item == 'SCRIPT_NAME')
-    check(weechat.hook_completion_get_string(completion, 'args') == 'w')
-    weechat.hook_completion_list_add(completion, 'word_completed',
-                                     0, weechat.WEECHAT_LIST_POS_END)
+    check(weechat.completion_get_string(completion, 'args') == 'w')
+    weechat.completion_list_add(completion, 'word_completed',
+                                0, weechat.WEECHAT_LIST_POS_END)
     return weechat.WEECHAT_RC_OK
 
 
