@@ -53,7 +53,7 @@ TEST_GROUP(CoreEval)
  *   eval_is_true
  */
 
-TEST(CoreEval, Boolean)
+TEST(CoreEval, IsTrue)
 {
     /* false */
     LONGS_EQUAL(0, eval_is_true (NULL));
@@ -146,10 +146,25 @@ TEST(CoreEval, EvalCondition)
     WEE_CHECK_EVAL("0", "abcd !~ ^ABC");
     WEE_CHECK_EVAL("0", "abcd !~ (?-i)^abc");
     WEE_CHECK_EVAL("0", "abcd!~abc");
+    WEE_CHECK_EVAL("0", "abcd ==* abce");
+    WEE_CHECK_EVAL("0", "abcd ==* ABCD");
+    WEE_CHECK_EVAL("0", "abcd ==* a*e");
+    WEE_CHECK_EVAL("0", "abcd ==* A*E");
+    WEE_CHECK_EVAL("0", "abcd !!* *bc*");
+    WEE_CHECK_EVAL("0", "abcd !!* *");
     WEE_CHECK_EVAL("0", "abcd =* abce");
     WEE_CHECK_EVAL("0", "abcd =* a*e");
+    WEE_CHECK_EVAL("0", "abcd =* A*E");
     WEE_CHECK_EVAL("0", "abcd !* *bc*");
+    WEE_CHECK_EVAL("0", "abcd !* *BC*");
     WEE_CHECK_EVAL("0", "abcd !* *");
+    WEE_CHECK_EVAL("0", "abcd ==- abce");
+    WEE_CHECK_EVAL("0", "abcd ==- ABCD");
+    WEE_CHECK_EVAL("0", "abcd ==- BC");
+    WEE_CHECK_EVAL("0", "abcd !!- bc");
+    WEE_CHECK_EVAL("0", "abcd =- abce");
+    WEE_CHECK_EVAL("0", "abcd !- bc");
+    WEE_CHECK_EVAL("0", "abcd !- BC");
     WEE_CHECK_EVAL("0", "${test} == test");
     WEE_CHECK_EVAL("0", "${test2} == value2");
     WEE_CHECK_EVAL("0", "${buffer.number} == 2");
@@ -215,10 +230,26 @@ TEST(CoreEval, EvalCondition)
     WEE_CHECK_EVAL("1", "abcd !~ (?-i)^ABC");
     WEE_CHECK_EVAL("1", "abcd !~ \\(abcd\\)");
     WEE_CHECK_EVAL("1", "!~abcd");
+    WEE_CHECK_EVAL("1", "abcd !!* abce");
+    WEE_CHECK_EVAL("1", "abcd !!* ABCD");
+    WEE_CHECK_EVAL("1", "abcd !!* a*e");
+    WEE_CHECK_EVAL("1", "abcd !!* A*E");
+    WEE_CHECK_EVAL("1", "abcd !!* *BC*");
+    WEE_CHECK_EVAL("1", "abcd ==* *bc*");
+    WEE_CHECK_EVAL("1", "abcd ==* *");
     WEE_CHECK_EVAL("1", "abcd !* abce");
     WEE_CHECK_EVAL("1", "abcd !* a*e");
+    WEE_CHECK_EVAL("1", "abcd !* A*E");
     WEE_CHECK_EVAL("1", "abcd =* *bc*");
+    WEE_CHECK_EVAL("1", "abcd =* *BC*");
     WEE_CHECK_EVAL("1", "abcd =* *");
+    WEE_CHECK_EVAL("1", "abcd !!- abce");
+    WEE_CHECK_EVAL("1", "abcd !!- ABCD");
+    WEE_CHECK_EVAL("1", "abcd !!- BC");
+    WEE_CHECK_EVAL("1", "abcd ==- bc");
+    WEE_CHECK_EVAL("1", "abcd !- abce");
+    WEE_CHECK_EVAL("1", "abcd =- bc");
+    WEE_CHECK_EVAL("1", "abcd =- BC");
     WEE_CHECK_EVAL("1", "${test} == value");
     WEE_CHECK_EVAL("1", "${test2} ==");
     WEE_CHECK_EVAL("1", "${buffer.number} == 1");
@@ -255,8 +286,14 @@ TEST(CoreEval, EvalCondition)
                  "eval_strstr_level(\"abc < def\", \"&&\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"=~\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"!~\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc < def\", \"==*\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc < def\", \"!!*\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"=*\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"!*\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc < def\", \"==-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc < def\", \"!!-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc < def\", \"=-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc < def\", \"!-\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"==\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"!=\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc < def\", \"<=\", \"(\", \")\", 0)\n"
@@ -266,8 +303,14 @@ TEST(CoreEval, EvalCondition)
                  "eval_strstr_level(\"abc\", \"&&\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"=~\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"!~\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc\", \"==*\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc\", \"!!*\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"=*\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"!*\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc\", \"==-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc\", \"!!-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc\", \"=-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"abc\", \"!-\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"==\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"!=\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"abc\", \"<=\", \"(\", \")\", 0)\n"
@@ -280,8 +323,14 @@ TEST(CoreEval, EvalCondition)
                  "eval_strstr_level(\"def\", \"&&\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"=~\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"!~\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"def\", \"==*\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"def\", \"!!*\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"=*\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"!*\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"def\", \"==-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"def\", \"!!-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"def\", \"=-\", \"(\", \")\", 0)\n"
+                 "eval_strstr_level(\"def\", \"!-\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"==\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"!=\", \"(\", \")\", 0)\n"
                  "eval_strstr_level(\"def\", \"<=\", \"(\", \")\", 0)\n"
@@ -481,15 +530,15 @@ TEST(CoreEval, EvalExpression)
               "%s-test-",
               gui_color_from_option (config_color_chat_delimiters));
     WEE_CHECK_EVAL(str_value, "${color:chat_delimiters}-test-");
-    config_file_search_with_string ("irc.color.message_join", NULL, NULL,
+    config_file_search_with_string ("weechat.color.chat_host", NULL, NULL,
                                     &ptr_option, NULL);
     if (!ptr_option)
     {
-        FAIL("ERROR: option irc.color.message_join not found.");
+        FAIL("ERROR: option weechat.color.chat_host not found.");
     }
     snprintf (str_value, sizeof (str_value),
               "%s-test-", gui_color_from_option (ptr_option));
-    WEE_CHECK_EVAL(str_value, "${color:irc.color.message_join}-test-");
+    WEE_CHECK_EVAL(str_value, "${color:weechat.color.chat_host}-test-");
     WEE_CHECK_EVAL("test", "${option.not.found}test");
 
     /* test modifier (invalid values) */
@@ -514,6 +563,22 @@ TEST(CoreEval, EvalExpression)
     /* test info */
     WEE_CHECK_EVAL(version_get_version (), "${info:version}");
 
+    /* test base_encode */
+    WEE_CHECK_EVAL("", "${base_encode:}");
+    WEE_CHECK_EVAL("", "${base_encode:0,xxx}");
+    WEE_CHECK_EVAL("", "${base_encode:100,test string}");
+    WEE_CHECK_EVAL("7465737420737472696E67", "${base_encode:16,test string}");
+    WEE_CHECK_EVAL("ORSXG5BAON2HE2LOM4======", "${base_encode:32,test string}");
+    WEE_CHECK_EVAL("dGVzdCBzdHJpbmc=", "${base_encode:64,test string}");
+
+    /* test base_decode */
+    WEE_CHECK_EVAL("", "${base_decode:}");
+    WEE_CHECK_EVAL("", "${base_decode:0,xxx}");
+    WEE_CHECK_EVAL("", "${base_decode:100,test string}");
+    WEE_CHECK_EVAL("test string", "${base_decode:16,7465737420737472696E67}");
+    WEE_CHECK_EVAL("test string", "${base_decode:32,ORSXG5BAON2HE2LOM4======}");
+    WEE_CHECK_EVAL("test string", "${base_decode:64,dGVzdCBzdHJpbmc=}");
+
     /* test date */
     WEE_CHECK_EVAL("", "${date:}");
     value = eval_expression ("${date}", pointers, extra_vars, options);
