@@ -33,6 +33,7 @@ extern "C"
 #include <regex.h>
 #include "tests/tests.h"
 #include "src/core/weechat.h"
+#include "src/core/wee-config.h"
 #include "src/core/wee-string.h"
 #include "src/core/wee-hashtable.h"
 #include "src/gui/gui-color.h"
@@ -107,6 +108,13 @@ extern "C"
     STRCMP_EQUAL(__result, str);                                        \
     free (str);
 
+#define WEE_HEX_DUMP(__result, __data, __size, __bytes_per_line,      \
+                     __prefix, __suffix)                                \
+    str = string_hex_dump (__data, __size, __bytes_per_line,            \
+                           __prefix, __suffix);                         \
+    STRCMP_EQUAL(__result, str);                                        \
+    free (str);
+
 extern struct t_hashtable *string_hashtable_shared;
 
 TEST_GROUP(CoreString)
@@ -1682,6 +1690,7 @@ TEST(CoreString, Base16)
         { { "", "" },
           { "abcdefgh", "6162636465666768" },
           { "this is a *test*", "746869732069732061202A746573742A" },
+          { "this is a *test*\xAA", "746869732069732061202A746573742AAA" },
           { NULL, NULL } };
 
 
@@ -1705,9 +1714,9 @@ TEST(CoreString, Base16)
     }
 
     /* string_base16_decode */
-    LONGS_EQUAL(0, string_base16_decode (NULL, NULL));
-    LONGS_EQUAL(0, string_base16_decode (NULL, str));
-    LONGS_EQUAL(0, string_base16_decode ("", NULL));
+    LONGS_EQUAL(-1, string_base16_decode (NULL, NULL));
+    LONGS_EQUAL(-1, string_base16_decode (NULL, str));
+    LONGS_EQUAL(-1, string_base16_decode ("", NULL));
     LONGS_EQUAL(0, string_base16_decode ("", str));
     for (i = 0; str_base16[i][0]; i++)
     {
@@ -1828,9 +1837,9 @@ TEST(CoreString, Base64)
     }
 
     /* string_base64_decode */
-    LONGS_EQUAL(0, string_base64_decode (NULL, NULL));
-    LONGS_EQUAL(0, string_base64_decode (NULL, str));
-    LONGS_EQUAL(0, string_base64_decode ("", NULL));
+    LONGS_EQUAL(-1, string_base64_decode (NULL, NULL));
+    LONGS_EQUAL(-1, string_base64_decode (NULL, str));
+    LONGS_EQUAL(-1, string_base64_decode ("", NULL));
     LONGS_EQUAL(0, string_base64_decode ("", str));
     for (i = 0; str_base64[i][0]; i++)
     {
@@ -1838,6 +1847,65 @@ TEST(CoreString, Base64)
         LONGS_EQUAL(length, string_base64_decode (str_base64[i][1], str));
         STRCMP_EQUAL(str_base64[i][0], str);
     }
+    /* invalid base64 string, missing two "=" at the end */
+    LONGS_EQUAL(4, string_base64_decode ("dGVzdA", str));
+    STRCMP_EQUAL("test", str);
+}
+
+/*
+ * Tests functions:
+ *    string_base_encode
+ */
+
+TEST(CoreString, BaseEncode)
+{
+    char str[1024];
+
+    LONGS_EQUAL(-1, string_base_encode (0, NULL, 0, NULL));
+    LONGS_EQUAL(-1, string_base_encode (0, "", 0, str));
+    LONGS_EQUAL(-1, string_base_encode (16, NULL, 0, str));
+    LONGS_EQUAL(-1, string_base_encode (32, NULL, 0, str));
+    LONGS_EQUAL(-1, string_base_encode (64, NULL, 0, str));
+
+    str[0] = 0xAA;
+    LONGS_EQUAL(16, string_base_encode (16, "abcdefgh", 8, str));
+    STRCMP_EQUAL("6162636465666768", str);
+
+    str[0] = 0xAA;
+    LONGS_EQUAL(16, string_base_encode (32, "abcdefgh", 8, str));
+    STRCMP_EQUAL("MFRGGZDFMZTWQ===", str);
+
+    str[0] = 0xAA;
+    LONGS_EQUAL(20, string_base_encode (64, "This is a test.", 15, str));
+    STRCMP_EQUAL("VGhpcyBpcyBhIHRlc3Qu", str);
+}
+
+/*
+ * Tests functions:
+ *    string_base_decode
+ */
+
+TEST(CoreString, BaseDecode)
+{
+    char str[1024];
+
+    LONGS_EQUAL(-1, string_base_decode (0, NULL, NULL));
+    LONGS_EQUAL(-1, string_base_decode (0, "", str));
+    LONGS_EQUAL(-1, string_base_decode (16, NULL, str));
+    LONGS_EQUAL(-1, string_base_decode (32, NULL, str));
+    LONGS_EQUAL(-1, string_base_decode (64, NULL, str));
+
+    str[0] = 0xAA;
+    LONGS_EQUAL(8, string_base_decode (16, "6162636465666768", str));
+    STRCMP_EQUAL("abcdefgh", str);
+
+    str[0] = 0xAA;
+    LONGS_EQUAL(8, string_base_decode (32, "MFRGGZDFMZTWQ===", str));
+    STRCMP_EQUAL("abcdefgh", str);
+
+    str[0] = 0xAA;
+    LONGS_EQUAL(15, string_base_decode (64, "VGhpcyBpcyBhIHRlc3Qu", str));
+    STRCMP_EQUAL("This is a test.", str);
 }
 
 /*
@@ -1856,71 +1924,45 @@ TEST(CoreString, Hex_dump)
     POINTERS_EQUAL(NULL, string_hex_dump ("abc", 3, 0, NULL, NULL));
     POINTERS_EQUAL(NULL, string_hex_dump ("abc", 0, 5, NULL, NULL));
 
-    str = string_hex_dump ("abc", 3, 3, NULL, NULL);
-    STRCMP_EQUAL("61 62 63   a b c ", str);
-
-    str = string_hex_dump ("abc", 3, 3, "", "");
-    STRCMP_EQUAL("61 62 63   a b c ", str);
-
-    str = string_hex_dump ("abc", 3, 3, "(( ", NULL);
-    STRCMP_EQUAL("(( 61 62 63   a b c ", str);
-
-    str = string_hex_dump ("abc", 3, 3, NULL, " ))");
-    STRCMP_EQUAL("61 62 63   a b c  ))", str);
-
-    str = string_hex_dump ("abc", 3, 3, "(( ", " ))");
-    STRCMP_EQUAL("(( 61 62 63   a b c  ))", str);
-
-    str = string_hex_dump ("abc", 3, 5, NULL, NULL);
-    STRCMP_EQUAL("61 62 63         a b c     ", str);
-
-    str = string_hex_dump ("abc", 3, 10, NULL, NULL);
-    STRCMP_EQUAL("61 62 63                        a b c               ", str);
-
-    str = string_hex_dump ("abc", 3, 2, NULL, NULL);
-    STRCMP_EQUAL("61 62   a b \n"
+    WEE_HEX_DUMP("61 62 63   a b c ", "abc", 3, 3, NULL, NULL);
+    WEE_HEX_DUMP("61 62 63   a b c ", "abc", 3, 3, "", "");
+    WEE_HEX_DUMP("(( 61 62 63   a b c ", "abc", 3, 3, "(( ", NULL);
+    WEE_HEX_DUMP("61 62 63   a b c  ))", "abc", 3, 3, NULL, " ))");
+    WEE_HEX_DUMP("(( 61 62 63   a b c  ))", "abc", 3, 3, "(( ", " ))");
+    WEE_HEX_DUMP("61 62 63         a b c     ", "abc", 3, 5, NULL, NULL);
+    WEE_HEX_DUMP("61 62 63                        a b c               ",
+                 "abc", 3, 10, NULL, NULL);
+    WEE_HEX_DUMP("61 62   a b \n"
                  "63      c   ",
-                 str);
-
-    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 5, NULL, NULL);
-    STRCMP_EQUAL("6E 6F C3 AB 6C   n o . . l ", str);
-
-    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 2, NULL, NULL);
-    STRCMP_EQUAL("6E 6F   n o \n"
+                 "abc", 3, 2, NULL, NULL);
+    WEE_HEX_DUMP("6E 6F C3 AB 6C   n o . . l ",
+                 noel_utf8, strlen (noel_utf8), 5, NULL, NULL);
+    WEE_HEX_DUMP("6E 6F   n o \n"
                  "C3 AB   . . \n"
                  "6C      l   ",
-                 str);
-    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 2, "( ", NULL);
-    STRCMP_EQUAL("( 6E 6F   n o \n"
+                 noel_utf8, strlen (noel_utf8), 2, NULL, NULL);
+    WEE_HEX_DUMP("( 6E 6F   n o \n"
                  "( C3 AB   . . \n"
                  "( 6C      l   ",
-                 str);
-    str = string_hex_dump (noel_utf8, strlen (noel_utf8), 2, "( ", " )");
-    STRCMP_EQUAL("( 6E 6F   n o  )\n"
+                 noel_utf8, strlen (noel_utf8), 2, "( ", NULL);
+    WEE_HEX_DUMP("( 6E 6F   n o  )\n"
                  "( C3 AB   . .  )\n"
                  "( 6C      l    )",
-                 str);
-
-    str = string_hex_dump (noel_iso, strlen (noel_iso), 5, NULL, NULL);
-    STRCMP_EQUAL("6E 6F EB 6C      n o . l   ", str);
-
-    str = string_hex_dump (noel_iso, strlen (noel_iso), 2, NULL, NULL);
-    STRCMP_EQUAL("6E 6F   n o \n"
+                 noel_utf8, strlen (noel_utf8), 2, "( ", " )");
+    WEE_HEX_DUMP("6E 6F EB 6C      n o . l   ",
+                 noel_iso, strlen (noel_iso), 5, NULL, NULL);
+    WEE_HEX_DUMP("6E 6F   n o \n"
                  "EB 6C   . l ",
-                 str);
+                 noel_iso, strlen (noel_iso), 2, NULL, NULL);
 }
 
 /*
  * Tests functions:
  *    string_is_command_char
- *    string_input_for_buffer
  */
 
-TEST(CoreString, Input)
+TEST(CoreString, IsCommandChar)
 {
-    char *str;
-
-    /* string_is_command_char */
     LONGS_EQUAL(0, string_is_command_char (NULL));
     LONGS_EQUAL(0, string_is_command_char (""));
     LONGS_EQUAL(0, string_is_command_char ("abc"));
@@ -1928,7 +1970,33 @@ TEST(CoreString, Input)
     LONGS_EQUAL(1, string_is_command_char ("/abc"));
     LONGS_EQUAL(1, string_is_command_char ("//abc"));
 
-    /* string_input_for_buffer */
+    /* test with custom command chars */
+    config_file_option_set (config_look_command_chars, "öï", 1);
+
+    LONGS_EQUAL(0, string_is_command_char ("abc"));
+    LONGS_EQUAL(0, string_is_command_char ("o_abc"));
+    LONGS_EQUAL(0, string_is_command_char ("i_abc"));
+    LONGS_EQUAL(0, string_is_command_char ("é_abc"));
+    LONGS_EQUAL(1, string_is_command_char ("ö"));
+    LONGS_EQUAL(1, string_is_command_char ("ö_abc"));
+    LONGS_EQUAL(1, string_is_command_char ("ö_öabc"));
+    LONGS_EQUAL(1, string_is_command_char ("ï"));
+    LONGS_EQUAL(1, string_is_command_char ("ï_abc"));
+    LONGS_EQUAL(1, string_is_command_char ("ï_öabc"));
+    LONGS_EQUAL(1, string_is_command_char ("/abc"));
+
+    config_file_option_reset (config_look_command_chars, 1);
+}
+
+/*
+ * Tests functions:
+ *    string_input_for_buffer
+ */
+
+TEST(CoreString, InputForBuffer)
+{
+    char *str;
+
     POINTERS_EQUAL(NULL, string_input_for_buffer (NULL));
     POINTERS_EQUAL(NULL, string_input_for_buffer ("/abc"));
     str = strdup ("");
@@ -1955,6 +2023,33 @@ TEST(CoreString, Input)
     str = strdup ("//abc");
     STRCMP_EQUAL(str + 1, string_input_for_buffer (str));
     free (str);
+
+    /* test with custom command chars */
+    config_file_option_set (config_look_command_chars, "öï", 1);
+
+    str = strdup ("o_abc");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("ö_abc");
+    POINTERS_EQUAL(NULL, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("ö abc");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("öö_abc");
+    STRCMP_EQUAL(str + 2, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("ï_abc");
+    POINTERS_EQUAL(NULL, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("ï abc");
+    STRCMP_EQUAL(str, string_input_for_buffer (str));
+    free (str);
+    str = strdup ("ïï_abc");
+    STRCMP_EQUAL(str + 2, string_input_for_buffer (str));
+    free (str);
+
+    config_file_option_reset (config_look_command_chars, 1);
 }
 
 /*
@@ -2065,7 +2160,7 @@ TEST(CoreString, Dyn)
     ptr_string_dyn = (struct t_string_dyn *)str;
 
     /* check concat with NULL */
-    LONGS_EQUAL(1, string_dyn_concat (str, NULL));
+    LONGS_EQUAL(1, string_dyn_concat (str, NULL, -1));
     LONGS_EQUAL(1, ptr_string_dyn->size_alloc);
     LONGS_EQUAL(1, ptr_string_dyn->size);
     POINTERS_EQUAL(ptr_string_dyn->string, *str);
@@ -2073,46 +2168,81 @@ TEST(CoreString, Dyn)
     STRCMP_EQUAL("", *str);
 
     /* check concat with an empty string */
-    LONGS_EQUAL(1, string_dyn_concat (str, ""));
+    LONGS_EQUAL(1, string_dyn_concat (str, "", -1));
     LONGS_EQUAL(1, ptr_string_dyn->size_alloc);
     LONGS_EQUAL(1, ptr_string_dyn->size);
     POINTERS_EQUAL(ptr_string_dyn->string, *str);
     STRCMP_EQUAL("", ptr_string_dyn->string);
     STRCMP_EQUAL("", *str);
 
-    /* check concat with some strings */
-    LONGS_EQUAL(1, string_dyn_concat (str, "a"));
+    /* check concat with some strings and automatic length */
+    LONGS_EQUAL(1, string_dyn_concat (str, "a", -1));
     LONGS_EQUAL(2, ptr_string_dyn->size_alloc);
     LONGS_EQUAL(2, ptr_string_dyn->size);
     POINTERS_EQUAL(ptr_string_dyn->string, *str);
     STRCMP_EQUAL("a", ptr_string_dyn->string);
     STRCMP_EQUAL("a", *str);
 
-    LONGS_EQUAL(1, string_dyn_concat (str, "bcd"));
+    LONGS_EQUAL(1, string_dyn_concat (str, "bcd", -1));
     LONGS_EQUAL(5, ptr_string_dyn->size_alloc);
     LONGS_EQUAL(5, ptr_string_dyn->size);
     POINTERS_EQUAL(ptr_string_dyn->string, *str);
     STRCMP_EQUAL("abcd", ptr_string_dyn->string);
     STRCMP_EQUAL("abcd", *str);
 
-    LONGS_EQUAL(1, string_dyn_concat (str, "e"));
+    LONGS_EQUAL(1, string_dyn_concat (str, "e", -1));
     LONGS_EQUAL(7, ptr_string_dyn->size_alloc);
     LONGS_EQUAL(6, ptr_string_dyn->size);
     POINTERS_EQUAL(ptr_string_dyn->string, *str);
     STRCMP_EQUAL("abcde", ptr_string_dyn->string);
     STRCMP_EQUAL("abcde", *str);
 
-    LONGS_EQUAL(1, string_dyn_concat (str, "fg"));
+    LONGS_EQUAL(1, string_dyn_concat (str, "fg", -1));
     LONGS_EQUAL(10, ptr_string_dyn->size_alloc);
     LONGS_EQUAL(8, ptr_string_dyn->size);
     POINTERS_EQUAL(ptr_string_dyn->string, *str);
     STRCMP_EQUAL("abcdefg", ptr_string_dyn->string);
     STRCMP_EQUAL("abcdefg", *str);
 
+    string_dyn_free (str, 1);
+
+    str = string_dyn_alloc (1);
+    ptr_string_dyn = (struct t_string_dyn *)str;
+
+    /* check concat with some strings and fixed length */
+    LONGS_EQUAL(1, string_dyn_copy (str, "abcd"));
+    LONGS_EQUAL(1, string_dyn_concat (str, "xyz", 0));
+    LONGS_EQUAL(5, ptr_string_dyn->size_alloc);
+    LONGS_EQUAL(5, ptr_string_dyn->size);
+    POINTERS_EQUAL(ptr_string_dyn->string, *str);
+    STRCMP_EQUAL("abcd", ptr_string_dyn->string);
+    STRCMP_EQUAL("abcd", *str);
+
+    LONGS_EQUAL(1, string_dyn_concat (str, "xyz", 1));
+    LONGS_EQUAL(7, ptr_string_dyn->size_alloc);
+    LONGS_EQUAL(6, ptr_string_dyn->size);
+    POINTERS_EQUAL(ptr_string_dyn->string, *str);
+    STRCMP_EQUAL("abcdx", ptr_string_dyn->string);
+    STRCMP_EQUAL("abcdx", *str);
+
+    LONGS_EQUAL(1, string_dyn_concat (str, "xyz", 2));
+    LONGS_EQUAL(10, ptr_string_dyn->size_alloc);
+    LONGS_EQUAL(8, ptr_string_dyn->size);
+    POINTERS_EQUAL(ptr_string_dyn->string, *str);
+    STRCMP_EQUAL("abcdxxy", ptr_string_dyn->string);
+    STRCMP_EQUAL("abcdxxy", *str);
+
+    LONGS_EQUAL(1, string_dyn_concat (str, "xyz", 3));
+    LONGS_EQUAL(15, ptr_string_dyn->size_alloc);
+    LONGS_EQUAL(11, ptr_string_dyn->size);
+    POINTERS_EQUAL(ptr_string_dyn->string, *str);
+    STRCMP_EQUAL("abcdxxyxyz", ptr_string_dyn->string);
+    STRCMP_EQUAL("abcdxxyxyz", *str);
+
     str_ptr = *str;
     string_dyn_free (str, 0);
 
-    STRCMP_EQUAL("abcdefg", str_ptr);
+    STRCMP_EQUAL("abcdxxyxyz", str_ptr);
 
     free (str_ptr);
 }
